// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"github.com/go-xorm/xorm"
	"LAPP_AS/dao/base/implments"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Interface Name           : CustomerDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : Customer的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
type CustomerDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Customer
	 *
	 * @Function Parameters      : 需要插入的Customer
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	InsertOne(*model.Customer) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Customer
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	DeleteOne(string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Customer
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Customer
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	SelectOne(string) (*model.Customer, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改Customer
	 *
	 * @Function Parameters      : 需要修改的Customer
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	UpdateOne(*model.Customer) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Customer
	 *
	 * @Function Parameters      : 需要插入的Customer列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	Insert(*[]model.Customer) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Customer
	 *
	 * @Function Parameters      : 需要删除的Customer列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	Delete(*[]model.Customer) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除Customer
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Customer
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.Customer, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Customer并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Customer
	 *
	 * @Function Parameters      : 需要修改的Customer列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	Update(*[]model.Customer) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改Customer
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.Customer, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewCustomerDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个CustomerDAO实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : CustomerDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func NewCustomerDAO(session *xorm.Session, plantNr int, userid string) CustomerDAO {
	return implments.NewCustomerDAOImplement(session, plantNr, userid)
}
