// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WorkPlaceGrpDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkPlaceGrp的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WorkPlaceGrpDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkPlaceGrpDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkPlaceGrpDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkPlaceGrpDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWorkPlaceGrpDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkPlaceGrpDAOImplement {
	return &WorkPlaceGrpDAOImplement{session, &meta.WorkPlaceGrp, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) InsertOne(entity *model.WorkPlaceGrp) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) DeleteOne(workPlaceGrpId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workPlaceGrpId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) SelectOne(workPlaceGrpId string) (*model.WorkPlaceGrp, error) {
	var data model.WorkPlaceGrp
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workPlaceGrpId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) UpdateOne(entity *model.WorkPlaceGrp) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) Insert(entities *[]model.WorkPlaceGrp) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) Delete(entities *[]model.WorkPlaceGrp) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkPlaceGrp_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.Select
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkPlaceGrp, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkPlaceGrp_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WorkPlaceGrp_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkPlaceGrp, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkPlaceGrp_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WorkPlaceGrp_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkPlaceGrp, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.Update
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) Update(entities *[]model.WorkPlaceGrp) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkPlaceGrp, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkPlaceGrp_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkPlaceGrp_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/base/WorkPlaceGrpDAO.SelectAll
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpDAOImplement) SelectAll() (entities []model.WorkPlaceGrp,err error) {
	session := impl.session.Table(impl.meta.TableName)
	if err = session.Where("PlantNr = ?",impl.plantNr).OrderBy("WorkPlaceGrpId").Find(&entities); err != nil{
		return nil,err
	}
	return entities,nil
}