// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/om"
	model "LAPP_AS/models/om"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WOOperationDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WOOperation的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WOOperationDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWOOperationDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WOOperationDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WOOperationDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWOOperationDAOImplement(session *xorm.Session, plantNr int, userid string) *WOOperationDAOImplement {
	return &WOOperationDAOImplement{session, &meta.WOOperation, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) InsertOne(entity *model.WOOperation) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) DeleteOne(workOrderId string, operationNr int, splitNr int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, operationNr, splitNr}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) SelectOne(workOrderId string, operationNr int, splitNr int) (*model.WOOperation, error) {
	var data model.WOOperation
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, operationNr, splitNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}

	// 获取工序的关联关系数据

	// 获取工序的物料数据
	if err = impl.session.Table(meta.WOOperationArtLst.TableName).Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		impl.plantNr, workOrderId, operationNr, splitNr).Find(&data.Artlst); err != nil{
		return nil, nil
	}
	// 获取工序的物料产出数据
	if err = impl.session.Table(meta.WOOperationYieldLst.TableName).Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		impl.plantNr, workOrderId, operationNr, splitNr).Find(&data.Yieldlst); err != nil{
		return nil, nil
	}
	// 获取工序的工具数据
	if err = impl.session.Table(meta.WOOperationToolLst.TableName).Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		impl.plantNr, workOrderId, operationNr, splitNr).Find(&data.Toollst); err != nil{
		return nil, nil
	}
	// 获取工序的技能数据
	if err = impl.session.Table(meta.WOOperationSkillLst.TableName).Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		impl.plantNr, workOrderId, operationNr, splitNr).Find(&data.Skilllst); err != nil{
		return nil, nil
	}
	// 获取工序的第二资源需求数据
	if err = impl.session.Table(meta.WOOperationResourceLst.TableName).Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		impl.plantNr, workOrderId, operationNr, splitNr).Find(&data.Resourcelst); err != nil{
		return nil, nil
	}

	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) UpdateOne(entity *model.WOOperation) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.Insert
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) Insert(entities *[]model.WOOperation) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.Delete
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) Delete(entities *[]model.WOOperation) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.Select
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WOOperation, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WOOperation_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WOOperation, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WOOperation_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WOOperation, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.Update
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) Update(entities *[]model.WOOperation) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WOOperationDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WOOperation, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WOOperation_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
