// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/om"
	model "LAPP_AS/models/om"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WOOperationStatusDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WOOperationStatus的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WOOperationStatusDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWOOperationStatusDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WOOperationStatusDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WOOperationStatusDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWOOperationStatusDAOImplement(session *xorm.Session, plantNr int, userid string) *WOOperationStatusDAOImplement {
	return &WOOperationStatusDAOImplement{session, &meta.WOOperationStatus, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) InsertOne(entity *model.WOOperationStatus) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) DeleteOne(workOrderId string, operationNr int, splitNr int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, operationNr, splitNr}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) SelectOne(workOrderId string, operationNr int, splitNr int) (*model.WOOperationStatus, error) {
	var data model.WOOperationStatus
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, operationNr, splitNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) UpdateOne(entity *model.WOOperationStatus) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.Insert
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) Insert(entities *[]model.WOOperationStatus) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.Delete
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) Delete(entities *[]model.WOOperationStatus) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperationStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.Select
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WOOperationStatus, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperationStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WOOperationStatus_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WOOperationStatus, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperationStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WOOperationStatus_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WOOperationStatus, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.Update
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) Update(entities *[]model.WOOperationStatus) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/dao/om/WOOperationStatusDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WOOperationStatusDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WOOperationStatus, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WOOperationStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WOOperationStatus_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
