// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package as

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/as"
	"LAPP_AS/services/as/implments"
)

/******************************************************************************
 *
 * @Interface Name           : SchedulerService
 *-----------------------------------------------------------------------------
 *
 * @Description              : Scheduler的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
type SchedulerService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Scheduler
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Scheduler
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.Scheduler) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Scheduler
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Scheduler
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Scheduler
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	SelectOne(*global.User, int) (*model.Scheduler, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条Scheduler
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Scheduler
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.Scheduler) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Scheduler
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Scheduler列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.Scheduler) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Scheduler
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的Scheduler列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.Scheduler) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询Scheduler
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.Scheduler, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询Scheduler
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Scheduler
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Scheduler列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 15:51:34
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.Scheduler) error



	Create(*global.User,  *model.Scheduler) error
}

/******************************************************************************
 *
 * @Function Name            : NewSchedulerService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SchedulerService
 *
 * @Return Value             : SchedulerService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func NewSchedulerService() SchedulerService {
	return implments.NewSchedulerServiceImplement()
}
