// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/as"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/as"
	model "LAPP_AS/models/as"
	service "LAPP_AS/services"
	"fmt"
	"time"
)

/******************************************************************************
 *
 * @Description              : Scheduler的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
var DefaultConditionOfScheduler = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Scheduler_SchedulerId.UrlParameterName: grmi.NewConditionItem(meta.Scheduler_SchedulerId, grmi.Equal, true),
		meta.Scheduler_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.Scheduler_LastModify, grmi.Approximate, false),
		meta.Scheduler_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.Scheduler_LastUser, grmi.Equal, false),
		meta.Scheduler_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.Scheduler_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Scheduler的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
var DefaultConditionOfSchedulerAndPaging = grmi.NewCondition(
	DefaultConditionOfScheduler.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : SchedulerServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Scheduler的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
type SchedulerServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewSchedulerDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SchedulerDAOImplement实例
 *
 * @Return Value             : SchedulerDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func NewSchedulerServiceImplement() *SchedulerServiceImplement {
	return &SchedulerServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.InsertOne
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) InsertOne(user *global.User, entity *model.Scheduler) error {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "InsertOneScheduler", "插入一个Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SchedulerId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.DeleteOne
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) DeleteOne(user *global.User, schedulerId int) error {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "DeleteOneScheduler", "删除一个Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(schedulerId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(schedulerId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.SelectOne
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) SelectOne(user *global.User, schedulerId int) (*model.Scheduler, error) {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "SelectOneScheduler", "查询一个Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(schedulerId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.UpdateOne
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) UpdateOne(user *global.User, entity *model.Scheduler) error {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "UpdateOneScheduler", "修改一个Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SchedulerId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.Insert
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) Insert(user *global.User, entities *[]model.Scheduler) error {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "InsertScheduler", "插入多个Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.Delete
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) Delete(user *global.User, entities *[]model.Scheduler) error {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "DeleteScheduler", "删除多个Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.Select
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Scheduler, error) {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "SelectScheduler", "查询Scheduler")

	condition := DefaultConditionOfSchedulerAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "SelectScheduler", "查询Scheduler")

	condition := DefaultConditionOfSchedulerAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/SchedulerService.Update
 *
 ******************************************************************************/
func (impl *SchedulerServiceImplement) Update(user *global.User, entities *[]model.Scheduler) error {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "UpdateScheduler", "修改多个Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}

func (impl *SchedulerServiceImplement) Create(user *global.User, entity *model.Scheduler) (error) {

	grmi.Log(user, "/services/as/implments/Scheduler.service.impl.go", "CreateScheduler", "创建Scheduler")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()


	var se service.SchedulerSrv

	st := time.Now()
	et := time.Now().Add(time.Hour*24*10)
	se.Init(100, st, et)

	// 加载时间模型主数据
	se.LoadTimeModelData()

	// 加载激活的项目
	se.LoadProjectData()

	// 加载工位主数据
	se.LoadWorkPlaceData()

	// 加载工具主数据
	se.LoadToolData()

	// 加载物料主数据，包括库存及在途
	se.LoadArticleData()

	// 加载人员主数据，包括技能
	se.LoadPersonData()

	// 加载辅助资源主数据
	se.LoadResourceData()

	// 加载订单主数据（未完成订单）
	se.LoadWorkOrderData()

	// 加载订单网络数据
	se.LoadOrderNetworkData()

	// 加载排程规则数据
	se.LoadScheduleRuleData()

	//约束
	se.SchedRule.ToolConstraintToggle = true

	// 遍历设备时间曲线，生成设备状态事件，推入队列
	for _, wp_p := range se.WorkPlaceDict{
		for _, tls := range wp_p.TimeCurve.TimeLineArray{
			evt1 := wp_p.GetAvailEvent(tls.StartTime)
			se.SchedEventQueue.Insert(evt1)
			evt2 := wp_p.GetUnAvailEvent(tls.EndTime)
			se.SchedEventQueue.Insert(evt2)
		}
	}

	// 载入订单首工序事件
	for _, ord_p := range se.OrderDict{
		for _, op_p := range ord_p.OperationDict {
			if len(op_p.PrevOpDict) <= 0 {
				evt := op_p.GetPlanStartEvent(time.Now())
				opet := evt.(service.OperationEvent)
				fmt.Println("压入订单工序事件：",opet.OrderId,opet.OperationNr, opet.TriggerTime)
				se.SchedEventQueue.Insert(evt)
			}
		}
	}

	// 启动订单调度引擎
	if err := se.Run(); err != nil{
		fmt.Println("调度错误:", err)
	}
	// 打印计划结果e
	fmt.Println("=========================================================>")
	for index, order := range se.OrderDict {
		fmt.Println(index)
		order.Print()
	}
	for index, wp := range se.WorkPlaceDict{
		fmt.Println(index)
		wp.Print()
	}
	for index, t := range se.ToolDict{
		fmt.Println(index)
		t.Print()
	}

	dao := dal.NewSchedulerDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SchedulerId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}

	return nil
}

