// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/as"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/as"
	model "LAPP_AS/models/as"
)

/******************************************************************************
 *
 * @Description              : WorkOrder的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
var DefaultConditionOfWorkOrder = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkOrder_SchedulerId.UrlParameterName: grmi.NewConditionItem(meta.WorkOrder_SchedulerId, grmi.Equal, true),
		meta.WorkOrder_WorkOrderId.UrlParameterName: grmi.NewConditionItem(meta.WorkOrder_WorkOrderId, grmi.Equal, true),
		meta.WorkOrder_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.WorkOrder_LastModify, grmi.Approximate, false),
		meta.WorkOrder_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.WorkOrder_LastUser, grmi.Equal, false),
		meta.WorkOrder_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.WorkOrder_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkOrder的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
var DefaultConditionOfWorkOrderAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkOrder.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WorkOrderServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkOrder的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
type WorkOrderServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkOrderDAOImplement实例
 *
 * @Return Value             : WorkOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func NewWorkOrderServiceImplement() *WorkOrderServiceImplement {
	return &WorkOrderServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) InsertOne(user *global.User, entity *model.WorkOrder) error {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "InsertOneWorkOrder", "插入一个WorkOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SchedulerId, entity.WorkOrderId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) DeleteOne(user *global.User, schedulerId int, workOrderId string) error {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "DeleteOneWorkOrder", "删除一个WorkOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(schedulerId, workOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(schedulerId, workOrderId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) SelectOne(user *global.User, schedulerId int, workOrderId string) (*model.WorkOrder, error) {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "SelectOneWorkOrder", "查询一个WorkOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(schedulerId, workOrderId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) UpdateOne(user *global.User, entity *model.WorkOrder) error {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "UpdateOneWorkOrder", "修改一个WorkOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SchedulerId, entity.WorkOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.Insert
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) Insert(user *global.User, entities *[]model.WorkOrder) error {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "InsertWorkOrder", "插入多个WorkOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId, entity.WorkOrderId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.Delete
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) Delete(user *global.User, entities *[]model.WorkOrder) error {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "DeleteWorkOrder", "删除多个WorkOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId, entity.WorkOrderId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.Select
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WorkOrder, error) {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "SelectWorkOrder", "查询WorkOrder")

	condition := DefaultConditionOfWorkOrderAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "SelectWorkOrder", "查询WorkOrder")

	condition := DefaultConditionOfWorkOrderAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkOrderService.Update
 *
 ******************************************************************************/
func (impl *WorkOrderServiceImplement) Update(user *global.User, entities *[]model.WorkOrder) error {

	grmi.Log(user, "/services/as/implments/WorkOrder.service.impl.go", "UpdateWorkOrder", "修改多个WorkOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId, entity.WorkOrderId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
