// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/as"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/as"
	model "LAPP_AS/models/as"
)

/******************************************************************************
 *
 * @Description              : WorkPlace的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
var DefaultConditionOfWorkPlace = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkPlace_SchedulerId.UrlParameterName: grmi.NewConditionItem(meta.WorkPlace_SchedulerId, grmi.Equal, true),
		meta.WorkPlace_WorkPlaceId.UrlParameterName: grmi.NewConditionItem(meta.WorkPlace_WorkPlaceId, grmi.Equal, true),
		meta.WorkPlace_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.WorkPlace_LastModify, grmi.Approximate, false),
		meta.WorkPlace_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.WorkPlace_LastUser, grmi.Equal, false),
		meta.WorkPlace_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.WorkPlace_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkPlace的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
var DefaultConditionOfWorkPlaceAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkPlace.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WorkPlaceServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkPlace的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
type WorkPlaceServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkPlaceDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkPlaceDAOImplement实例
 *
 * @Return Value             : WorkPlaceDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func NewWorkPlaceServiceImplement() *WorkPlaceServiceImplement {
	return &WorkPlaceServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) InsertOne(user *global.User, entity *model.WorkPlace) error {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "InsertOneWorkPlace", "插入一个WorkPlace")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SchedulerId, entity.WorkPlaceId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) DeleteOne(user *global.User, schedulerId int, workPlaceId string) error {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "DeleteOneWorkPlace", "删除一个WorkPlace")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(schedulerId, workPlaceId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(schedulerId, workPlaceId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) SelectOne(user *global.User, schedulerId int, workPlaceId string) (*model.WorkPlace, error) {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "SelectOneWorkPlace", "查询一个WorkPlace")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(schedulerId, workPlaceId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) UpdateOne(user *global.User, entity *model.WorkPlace) error {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "UpdateOneWorkPlace", "修改一个WorkPlace")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SchedulerId, entity.WorkPlaceId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.Insert
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) Insert(user *global.User, entities *[]model.WorkPlace) error {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "InsertWorkPlace", "插入多个WorkPlace")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId, entity.WorkPlaceId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.Delete
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) Delete(user *global.User, entities *[]model.WorkPlace) error {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "DeleteWorkPlace", "删除多个WorkPlace")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId, entity.WorkPlaceId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.Select
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WorkPlace, error) {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "SelectWorkPlace", "查询WorkPlace")

	condition := DefaultConditionOfWorkPlaceAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "SelectWorkPlace", "查询WorkPlace")

	condition := DefaultConditionOfWorkPlaceAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/as/WorkPlaceService.Update
 *
 ******************************************************************************/
func (impl *WorkPlaceServiceImplement) Update(user *global.User, entities *[]model.WorkPlace) error {

	grmi.Log(user, "/services/as/implments/WorkPlace.service.impl.go", "UpdateWorkPlace", "修改多个WorkPlace")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SchedulerId, entity.WorkPlaceId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
