// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/base"
	"LAPP_AS/services/base/implments"
)

/******************************************************************************
 *
 * @Interface Name           : SecondaryResourceService
 *-----------------------------------------------------------------------------
 *
 * @Description              : SecondaryResource的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type SecondaryResourceService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条SecondaryResource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的SecondaryResource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.SecondaryResource) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的SecondaryResource
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的SecondaryResource
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的SecondaryResource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	SelectOne(*global.User, string) (*model.SecondaryResource, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条SecondaryResource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的SecondaryResource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.SecondaryResource) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条SecondaryResource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的SecondaryResource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.SecondaryResource) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条SecondaryResource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的SecondaryResource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.SecondaryResource) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询SecondaryResource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.SecondaryResource, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询SecondaryResource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条SecondaryResource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的SecondaryResource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.SecondaryResource) error
}

/******************************************************************************
 *
 * @Function Name            : NewSecondaryResourceService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SecondaryResourceService
 *
 * @Return Value             : SecondaryResourceService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewSecondaryResourceService() SecondaryResourceService {
	return implments.NewSecondaryResourceServiceImplement()
}
