// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : ArticleAtcodLst的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfArticleAtcodLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ArticleAtcodLst_ArtId.UrlParameterName:      grmi.NewConditionItem(meta.ArticleAtcodLst_ArtId, grmi.Equal, true),
		meta.ArticleAtcodLst_Version.UrlParameterName:    grmi.NewConditionItem(meta.ArticleAtcodLst_Version, grmi.Equal, true),
		meta.ArticleAtcodLst_ProjectId.UrlParameterName:  grmi.NewConditionItem(meta.ArticleAtcodLst_ProjectId, grmi.Equal, true),
		meta.ArticleAtcodLst_AttrCode.UrlParameterName:   grmi.NewConditionItem(meta.ArticleAtcodLst_AttrCode, grmi.Equal, true),
		meta.ArticleAtcodLst_AttrValue.UrlParameterName:  grmi.NewConditionItem(meta.ArticleAtcodLst_AttrValue, grmi.Equal, true),
		meta.ArticleAtcodLst_LastModify.UrlParameterName: grmi.NewConditionItem(meta.ArticleAtcodLst_LastModify, grmi.Approximate, false),
		meta.ArticleAtcodLst_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.ArticleAtcodLst_LastUser, grmi.Equal, false),
		meta.ArticleAtcodLst_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.ArticleAtcodLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ArticleAtcodLst的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfArticleAtcodLstAndPaging = grmi.NewCondition(
	DefaultConditionOfArticleAtcodLst.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ArticleAtcodLstServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArticleAtcodLst的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
type ArticleAtcodLstServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewArticleAtcodLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArticleAtcodLstDAOImplement实例
 *
 * @Return Value             : ArticleAtcodLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func NewArticleAtcodLstServiceImplement() *ArticleAtcodLstServiceImplement {
	return &ArticleAtcodLstServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.InsertOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) InsertOne(user *global.User, entity *model.ArticleAtcodLst) error {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "InsertOneArticleAtcodLst", "插入一个ArticleAtcodLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ArtId, entity.Version, entity.ProjectId, entity.AttrCode, entity.AttrValue)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.DeleteOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) DeleteOne(user *global.User, artId string, version int, projectId string, attrCode int, attrValue string) error {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "DeleteOneArticleAtcodLst", "删除一个ArticleAtcodLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(artId, version, projectId, attrCode, attrValue)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId, version, projectId, attrCode, attrValue)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.SelectOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) SelectOne(user *global.User, artId string, version int, projectId string, attrCode int, attrValue string) (*model.ArticleAtcodLst, error) {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "SelectOneArticleAtcodLst", "查询一个ArticleAtcodLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(artId, version, projectId, attrCode, attrValue)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.UpdateOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) UpdateOne(user *global.User, entity *model.ArticleAtcodLst) error {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "UpdateOneArticleAtcodLst", "修改一个ArticleAtcodLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ArtId, entity.Version, entity.ProjectId, entity.AttrCode, entity.AttrValue)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.Insert
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) Insert(user *global.User, entities *[]model.ArticleAtcodLst) error {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "InsertArticleAtcodLst", "插入多个ArticleAtcodLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.Version, entity.ProjectId, entity.AttrCode, entity.AttrValue)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.Delete
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) Delete(user *global.User, entities *[]model.ArticleAtcodLst) error {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "DeleteArticleAtcodLst", "删除多个ArticleAtcodLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.Version, entity.ProjectId, entity.AttrCode, entity.AttrValue)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.Select
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.ArticleAtcodLst, error) {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "SelectArticleAtcodLst", "查询ArticleAtcodLst")

	condition := DefaultConditionOfArticleAtcodLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "SelectArticleAtcodLst", "查询ArticleAtcodLst")

	condition := DefaultConditionOfArticleAtcodLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ArticleAtcodLstService.Update
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstServiceImplement) Update(user *global.User, entities *[]model.ArticleAtcodLst) error {

	grmi.Log(user, "/services/base/implments/ArticleAtcodLst.service.impl.go", "UpdateArticleAtcodLst", "修改多个ArticleAtcodLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArticleAtcodLstDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.Version, entity.ProjectId, entity.AttrCode, entity.AttrValue)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
