// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : Customer的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfCustomer = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Customer_CustomerId.UrlParameterName:       grmi.NewConditionItem(meta.Customer_CustomerId, grmi.Equal, true),
		meta.Customer_Name1.UrlParameterName:            grmi.NewConditionItem(meta.Customer_Name1, grmi.Equal, false),
		meta.Customer_Name2.UrlParameterName:            grmi.NewConditionItem(meta.Customer_Name2, grmi.Equal, false),
		meta.Customer_CustomerType.UrlParameterName:     grmi.NewConditionItem(meta.Customer_CustomerType, grmi.Equal, false),
		meta.Customer_DemandModelId.UrlParameterName:    grmi.NewConditionItem(meta.Customer_DemandModelId, grmi.Equal, false),
		meta.Customer_ToleranceModelId.UrlParameterName: grmi.NewConditionItem(meta.Customer_ToleranceModelId, grmi.Equal, false),
		meta.Customer_ValidStartDate.UrlParameterName:   grmi.NewConditionItem(meta.Customer_ValidStartDate, grmi.Approximate, false),
		meta.Customer_Country.UrlParameterName:          grmi.NewConditionItem(meta.Customer_Country, grmi.Equal, false),
		meta.Customer_City.UrlParameterName:             grmi.NewConditionItem(meta.Customer_City, grmi.Equal, false),
		meta.Customer_District.UrlParameterName:         grmi.NewConditionItem(meta.Customer_District, grmi.Equal, false),
		meta.Customer_Street.UrlParameterName:           grmi.NewConditionItem(meta.Customer_Street, grmi.Equal, false),
		meta.Customer_Location.UrlParameterName:         grmi.NewConditionItem(meta.Customer_Location, grmi.Equal, false),
		meta.Customer_PostCode.UrlParameterName:         grmi.NewConditionItem(meta.Customer_PostCode, grmi.Equal, false),
		meta.Customer_Phone.UrlParameterName:            grmi.NewConditionItem(meta.Customer_Phone, grmi.Equal, false),
		meta.Customer_Mobile.UrlParameterName:           grmi.NewConditionItem(meta.Customer_Mobile, grmi.Equal, false),
		meta.Customer_Fax.UrlParameterName:              grmi.NewConditionItem(meta.Customer_Fax, grmi.Equal, false),
		meta.Customer_Email1.UrlParameterName:           grmi.NewConditionItem(meta.Customer_Email1, grmi.Equal, false),
		meta.Customer_Email2.UrlParameterName:           grmi.NewConditionItem(meta.Customer_Email2, grmi.Equal, false),
		meta.Customer_ContactPerson.UrlParameterName:    grmi.NewConditionItem(meta.Customer_ContactPerson, grmi.Equal, false),
		meta.Customer_PersonTitle.UrlParameterName:      grmi.NewConditionItem(meta.Customer_PersonTitle, grmi.Equal, false),
		meta.Customer_ContactAddress.UrlParameterName:   grmi.NewConditionItem(meta.Customer_ContactAddress, grmi.Equal, false),
		meta.Customer_Account.UrlParameterName:          grmi.NewConditionItem(meta.Customer_Account, grmi.Equal, false),
		meta.Customer_TaxRate.UrlParameterName:          grmi.NewConditionItem(meta.Customer_TaxRate, grmi.Equal, false),
		meta.Customer_Status.UrlParameterName:           grmi.NewConditionItem(meta.Customer_Status, grmi.Equal, false),
		meta.Customer_CtrlPara1.UrlParameterName:        grmi.NewConditionItem(meta.Customer_CtrlPara1, grmi.Equal, false),
		meta.Customer_CtrlPara2.UrlParameterName:        grmi.NewConditionItem(meta.Customer_CtrlPara2, grmi.Equal, false),
		meta.Customer_CtrlStr1.UrlParameterName:         grmi.NewConditionItem(meta.Customer_CtrlStr1, grmi.Equal, false),
		meta.Customer_CtrlStr2.UrlParameterName:         grmi.NewConditionItem(meta.Customer_CtrlStr2, grmi.Equal, false),
		meta.Customer_CtrlTime1.UrlParameterName:        grmi.NewConditionItem(meta.Customer_CtrlTime1, grmi.Approximate, false),
		meta.Customer_CtrlTime2.UrlParameterName:        grmi.NewConditionItem(meta.Customer_CtrlTime2, grmi.Approximate, false),
		meta.Customer_LastModify.UrlParameterName:       grmi.NewConditionItem(meta.Customer_LastModify, grmi.Approximate, false),
		meta.Customer_LastUser.UrlParameterName:         grmi.NewConditionItem(meta.Customer_LastUser, grmi.Equal, false),
		meta.Customer_CreateTime.UrlParameterName:       grmi.NewConditionItem(meta.Customer_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Customer的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfCustomerAndPaging = grmi.NewCondition(
	DefaultConditionOfCustomer.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : CustomerServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Customer的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
type CustomerServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewCustomerDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个CustomerDAOImplement实例
 *
 * @Return Value             : CustomerDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func NewCustomerServiceImplement() *CustomerServiceImplement {
	return &CustomerServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.InsertOne
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) InsertOne(user *global.User, entity *model.Customer) error {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "InsertOneCustomer", "插入一个Customer")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.CustomerId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.DeleteOne
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) DeleteOne(user *global.User, customerId string) error {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "DeleteOneCustomer", "删除一个Customer")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(customerId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(customerId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.SelectOne
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) SelectOne(user *global.User, customerId string) (*model.Customer, error) {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "SelectOneCustomer", "查询一个Customer")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(customerId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.UpdateOne
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) UpdateOne(user *global.User, entity *model.Customer) error {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "UpdateOneCustomer", "修改一个Customer")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.CustomerId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.Insert
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) Insert(user *global.User, entities *[]model.Customer) error {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "InsertCustomer", "插入多个Customer")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.CustomerId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.Delete
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) Delete(user *global.User, entities *[]model.Customer) error {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "DeleteCustomer", "删除多个Customer")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.CustomerId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.Select
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Customer, error) {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "SelectCustomer", "查询Customer")

	condition := DefaultConditionOfCustomerAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "SelectCustomer", "查询Customer")

	condition := DefaultConditionOfCustomerAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/CustomerService.Update
 *
 ******************************************************************************/
func (impl *CustomerServiceImplement) Update(user *global.User, entities *[]model.Customer) error {

	grmi.Log(user, "/services/base/implments/Customer.service.impl.go", "UpdateCustomer", "修改多个Customer")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCustomerDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.CustomerId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
