// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : Person的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfPerson = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Person_PersonNr.UrlParameterName:     grmi.NewConditionItem(meta.Person_PersonNr, grmi.Equal, true),
		meta.Person_PersonId.UrlParameterName:     grmi.NewConditionItem(meta.Person_PersonId, grmi.Equal, false),
		meta.Person_Name.UrlParameterName:         grmi.NewConditionItem(meta.Person_Name, grmi.Equal, false),
		meta.Person_Status.UrlParameterName:       grmi.NewConditionItem(meta.Person_Status, grmi.Equal, false),
		meta.Person_CostCenterId.UrlParameterName: grmi.NewConditionItem(meta.Person_CostCenterId, grmi.Equal, false),
		meta.Person_DepartmentId.UrlParameterName: grmi.NewConditionItem(meta.Person_DepartmentId, grmi.Equal, false),
		meta.Person_SalaryGrpId.UrlParameterName:  grmi.NewConditionItem(meta.Person_SalaryGrpId, grmi.Equal, false),
		meta.Person_BonusGrpId.UrlParameterName:   grmi.NewConditionItem(meta.Person_BonusGrpId, grmi.Equal, false),
		meta.Person_EntryDate.UrlParameterName:    grmi.NewConditionItem(meta.Person_EntryDate, grmi.Approximate, false),
		meta.Person_BirthDate.UrlParameterName:    grmi.NewConditionItem(meta.Person_BirthDate, grmi.Approximate, false),
		meta.Person_Avatar.UrlParameterName:       grmi.NewConditionItem(meta.Person_Avatar, grmi.Equal, false),
		meta.Person_PersonIPara1.UrlParameterName: grmi.NewConditionItem(meta.Person_PersonIPara1, grmi.Equal, false),
		meta.Person_PersonIPara2.UrlParameterName: grmi.NewConditionItem(meta.Person_PersonIPara2, grmi.Equal, false),
		meta.Person_PersonDPara1.UrlParameterName: grmi.NewConditionItem(meta.Person_PersonDPara1, grmi.Equal, false),
		meta.Person_PersonDPara2.UrlParameterName: grmi.NewConditionItem(meta.Person_PersonDPara2, grmi.Equal, false),
		meta.Person_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.Person_LastModify, grmi.Approximate, false),
		meta.Person_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.Person_LastUser, grmi.Equal, false),
		meta.Person_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.Person_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Person的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfPersonAndPaging = grmi.NewCondition(
	DefaultConditionOfPerson.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : PersonServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Person的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type PersonServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewPersonDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PersonDAOImplement实例
 *
 * @Return Value             : PersonDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewPersonServiceImplement() *PersonServiceImplement {
	return &PersonServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.InsertOne
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) InsertOne(user *global.User, entity *model.Person) error {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "InsertOnePerson", "插入一个Person")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.PersonNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.DeleteOne
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) DeleteOne(user *global.User, personNr int) error {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "DeleteOnePerson", "删除一个Person")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(personNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(personNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.SelectOne
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) SelectOne(user *global.User, personNr int) (*model.Person, error) {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "SelectOnePerson", "查询一个Person")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(personNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.UpdateOne
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) UpdateOne(user *global.User, entity *model.Person) error {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "UpdateOnePerson", "修改一个Person")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.PersonNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.Insert
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) Insert(user *global.User, entities *[]model.Person) error {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "InsertPerson", "插入多个Person")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.PersonNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.Delete
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) Delete(user *global.User, entities *[]model.Person) error {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "DeletePerson", "删除多个Person")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.PersonNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.Select
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Person, error) {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "SelectPerson", "查询Person")

	condition := DefaultConditionOfPersonAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "SelectPerson", "查询Person")

	condition := DefaultConditionOfPersonAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/PersonService.Update
 *
 ******************************************************************************/
func (impl *PersonServiceImplement) Update(user *global.User, entities *[]model.Person) error {

	grmi.Log(user, "/services/base/implments/Person.service.impl.go", "UpdatePerson", "修改多个Person")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPersonDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.PersonNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
