// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : SecondaryResource的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfSecondaryResource = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.SecondaryResource_ResourceId.UrlParameterName:     grmi.NewConditionItem(meta.SecondaryResource_ResourceId, grmi.Equal, true),
		meta.SecondaryResource_Descr.UrlParameterName:          grmi.NewConditionItem(meta.SecondaryResource_Descr, grmi.Equal, false),
		meta.SecondaryResource_ResourceType.UrlParameterName:   grmi.NewConditionItem(meta.SecondaryResource_ResourceType, grmi.Equal, false),
		meta.SecondaryResource_CapacityType.UrlParameterName:   grmi.NewConditionItem(meta.SecondaryResource_CapacityType, grmi.Equal, false),
		meta.SecondaryResource_CapacityFactor.UrlParameterName: grmi.NewConditionItem(meta.SecondaryResource_CapacityFactor, grmi.Equal, false),
		meta.SecondaryResource_PlanEfficiency.UrlParameterName: grmi.NewConditionItem(meta.SecondaryResource_PlanEfficiency, grmi.Equal, false),
		meta.SecondaryResource_CostRate.UrlParameterName:       grmi.NewConditionItem(meta.SecondaryResource_CostRate, grmi.Equal, false),
		meta.SecondaryResource_WeekModelNr.UrlParameterName:    grmi.NewConditionItem(meta.SecondaryResource_WeekModelNr, grmi.Equal, false),
		meta.SecondaryResource_WorkCalendarNr.UrlParameterName: grmi.NewConditionItem(meta.SecondaryResource_WorkCalendarNr, grmi.Equal, false),
		meta.SecondaryResource_CostCenterId.UrlParameterName:   grmi.NewConditionItem(meta.SecondaryResource_CostCenterId, grmi.Equal, false),
		meta.SecondaryResource_LocationId.UrlParameterName:     grmi.NewConditionItem(meta.SecondaryResource_LocationId, grmi.Equal, false),
		meta.SecondaryResource_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.SecondaryResource_LastModify, grmi.Approximate, false),
		meta.SecondaryResource_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.SecondaryResource_LastUser, grmi.Equal, false),
		meta.SecondaryResource_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.SecondaryResource_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : SecondaryResource的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfSecondaryResourceAndPaging = grmi.NewCondition(
	DefaultConditionOfSecondaryResource.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : SecondaryResourceServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : SecondaryResource的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type SecondaryResourceServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewSecondaryResourceDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SecondaryResourceDAOImplement实例
 *
 * @Return Value             : SecondaryResourceDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewSecondaryResourceServiceImplement() *SecondaryResourceServiceImplement {
	return &SecondaryResourceServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.InsertOne
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) InsertOne(user *global.User, entity *model.SecondaryResource) error {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "InsertOneSecondaryResource", "插入一个SecondaryResource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ResourceId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.DeleteOne
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) DeleteOne(user *global.User, resourceId string) error {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "DeleteOneSecondaryResource", "删除一个SecondaryResource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(resourceId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(resourceId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.SelectOne
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) SelectOne(user *global.User, resourceId string) (*model.SecondaryResource, error) {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "SelectOneSecondaryResource", "查询一个SecondaryResource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(resourceId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.UpdateOne
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) UpdateOne(user *global.User, entity *model.SecondaryResource) error {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "UpdateOneSecondaryResource", "修改一个SecondaryResource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ResourceId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.Insert
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) Insert(user *global.User, entities *[]model.SecondaryResource) error {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "InsertSecondaryResource", "插入多个SecondaryResource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ResourceId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.Delete
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) Delete(user *global.User, entities *[]model.SecondaryResource) error {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "DeleteSecondaryResource", "删除多个SecondaryResource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ResourceId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.Select
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.SecondaryResource, error) {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "SelectSecondaryResource", "查询SecondaryResource")

	condition := DefaultConditionOfSecondaryResourceAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "SelectSecondaryResource", "查询SecondaryResource")

	condition := DefaultConditionOfSecondaryResourceAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SecondaryResourceService.Update
 *
 ******************************************************************************/
func (impl *SecondaryResourceServiceImplement) Update(user *global.User, entities *[]model.SecondaryResource) error {

	grmi.Log(user, "/services/base/implments/SecondaryResource.service.impl.go", "UpdateSecondaryResource", "修改多个SecondaryResource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSecondaryResourceDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ResourceId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
