// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : Skill的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfSkill = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Skill_SkillId.UrlParameterName:    grmi.NewConditionItem(meta.Skill_SkillId, grmi.Equal, true),
		meta.Skill_Abrev.UrlParameterName:      grmi.NewConditionItem(meta.Skill_Abrev, grmi.Equal, false),
		meta.Skill_Descr.UrlParameterName:      grmi.NewConditionItem(meta.Skill_Descr, grmi.Equal, false),
		meta.Skill_SkillType.UrlParameterName:  grmi.NewConditionItem(meta.Skill_SkillType, grmi.Equal, false),
		meta.Skill_CtrlPara1.UrlParameterName:  grmi.NewConditionItem(meta.Skill_CtrlPara1, grmi.Equal, false),
		meta.Skill_CtrlPara2.UrlParameterName:  grmi.NewConditionItem(meta.Skill_CtrlPara2, grmi.Equal, false),
		meta.Skill_CtrlStr1.UrlParameterName:   grmi.NewConditionItem(meta.Skill_CtrlStr1, grmi.Equal, false),
		meta.Skill_CtrlStr2.UrlParameterName:   grmi.NewConditionItem(meta.Skill_CtrlStr2, grmi.Equal, false),
		meta.Skill_LastModify.UrlParameterName: grmi.NewConditionItem(meta.Skill_LastModify, grmi.Approximate, false),
		meta.Skill_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.Skill_LastUser, grmi.Equal, false),
		meta.Skill_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.Skill_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Skill的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfSkillAndPaging = grmi.NewCondition(
	DefaultConditionOfSkill.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : SkillServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Skill的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type SkillServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewSkillDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SkillDAOImplement实例
 *
 * @Return Value             : SkillDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewSkillServiceImplement() *SkillServiceImplement {
	return &SkillServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.InsertOne
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) InsertOne(user *global.User, entity *model.Skill) error {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "InsertOneSkill", "插入一个Skill")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SkillId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.DeleteOne
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) DeleteOne(user *global.User, skillId string) error {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "DeleteOneSkill", "删除一个Skill")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(skillId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(skillId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.SelectOne
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) SelectOne(user *global.User, skillId string) (*model.Skill, error) {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "SelectOneSkill", "查询一个Skill")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(skillId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.UpdateOne
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) UpdateOne(user *global.User, entity *model.Skill) error {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "UpdateOneSkill", "修改一个Skill")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.SkillId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.Insert
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) Insert(user *global.User, entities *[]model.Skill) error {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "InsertSkill", "插入多个Skill")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SkillId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.Delete
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) Delete(user *global.User, entities *[]model.Skill) error {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "DeleteSkill", "删除多个Skill")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SkillId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.Select
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Skill, error) {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "SelectSkill", "查询Skill")

	condition := DefaultConditionOfSkillAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "SelectSkill", "查询Skill")

	condition := DefaultConditionOfSkillAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/SkillService.Update
 *
 ******************************************************************************/
func (impl *SkillServiceImplement) Update(user *global.User, entities *[]model.Skill) error {

	grmi.Log(user, "/services/base/implments/Skill.service.impl.go", "UpdateSkill", "修改多个Skill")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewSkillDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.SkillId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
