// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : Tool的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfTool = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Tool_ToolId.UrlParameterName:                   grmi.NewConditionItem(meta.Tool_ToolId, grmi.Equal, true),
		meta.Tool_ToolGrpId.UrlParameterName:                grmi.NewConditionItem(meta.Tool_ToolGrpId, grmi.Equal, false),
		meta.Tool_Descr.UrlParameterName:                    grmi.NewConditionItem(meta.Tool_Descr, grmi.Equal, false),
		meta.Tool_ProjectId.UrlParameterName:                grmi.NewConditionItem(meta.Tool_ProjectId, grmi.Equal, false),
		meta.Tool_Status.UrlParameterName:                   grmi.NewConditionItem(meta.Tool_Status, grmi.Equal, false),
		meta.Tool_AvailQty.UrlParameterName:                 grmi.NewConditionItem(meta.Tool_AvailQty, grmi.Equal, false),
		meta.Tool_ToolType.UrlParameterName:                 grmi.NewConditionItem(meta.Tool_ToolType, grmi.Equal, false),
		meta.Tool_AlternativeToolId.UrlParameterName:        grmi.NewConditionItem(meta.Tool_AlternativeToolId, grmi.Equal, false),
		meta.Tool_FrozenToggle.UrlParameterName:             grmi.NewConditionItem(meta.Tool_FrozenToggle, grmi.Equal, false),
		meta.Tool_Icon.UrlParameterName:                     grmi.NewConditionItem(meta.Tool_Icon, grmi.Equal, false),
		meta.Tool_Document.UrlParameterName:                 grmi.NewConditionItem(meta.Tool_Document, grmi.Equal, false),
		meta.Tool_CostRate.UrlParameterName:                 grmi.NewConditionItem(meta.Tool_CostRate, grmi.Equal, false),
		meta.Tool_CostCenterId.UrlParameterName:             grmi.NewConditionItem(meta.Tool_CostCenterId, grmi.Equal, false),
		meta.Tool_LocationId.UrlParameterName:               grmi.NewConditionItem(meta.Tool_LocationId, grmi.Equal, false),
		meta.Tool_Manufacturer.UrlParameterName:             grmi.NewConditionItem(meta.Tool_Manufacturer, grmi.Equal, false),
		meta.Tool_ManufactureDate.UrlParameterName:          grmi.NewConditionItem(meta.Tool_ManufactureDate, grmi.Approximate, false),
		meta.Tool_MaintenanceWay.UrlParameterName:           grmi.NewConditionItem(meta.Tool_MaintenanceWay, grmi.Equal, false),
		meta.Tool_LastMaintenanceDate.UrlParameterName:      grmi.NewConditionItem(meta.Tool_LastMaintenanceDate, grmi.Approximate, false),
		meta.Tool_MaintenanceCtrlValue.UrlParameterName:     grmi.NewConditionItem(meta.Tool_MaintenanceCtrlValue, grmi.Equal, false),
		meta.Tool_LastMaintenanceCtrlValue.UrlParameterName: grmi.NewConditionItem(meta.Tool_LastMaintenanceCtrlValue, grmi.Equal, false),
		meta.Tool_ExperationWay.UrlParameterName:            grmi.NewConditionItem(meta.Tool_ExperationWay, grmi.Equal, false),
		meta.Tool_ExperationDate.UrlParameterName:           grmi.NewConditionItem(meta.Tool_ExperationDate, grmi.Approximate, false),
		meta.Tool_ExperationCtrlValue.UrlParameterName:      grmi.NewConditionItem(meta.Tool_ExperationCtrlValue, grmi.Equal, false),
		meta.Tool_LastExperationCtrlValue.UrlParameterName:  grmi.NewConditionItem(meta.Tool_LastExperationCtrlValue, grmi.Equal, false),
		meta.Tool_LastModify.UrlParameterName:               grmi.NewConditionItem(meta.Tool_LastModify, grmi.Approximate, false),
		meta.Tool_LastUser.UrlParameterName:                 grmi.NewConditionItem(meta.Tool_LastUser, grmi.Equal, false),
		meta.Tool_CreateTime.UrlParameterName:               grmi.NewConditionItem(meta.Tool_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Tool的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfToolAndPaging = grmi.NewCondition(
	DefaultConditionOfTool.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ToolServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Tool的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type ToolServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewToolDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ToolDAOImplement实例
 *
 * @Return Value             : ToolDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewToolServiceImplement() *ToolServiceImplement {
	return &ToolServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.InsertOne
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) InsertOne(user *global.User, entity *model.Tool) error {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "InsertOneTool", "插入一个Tool")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ToolId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.DeleteOne
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) DeleteOne(user *global.User, toolId string) error {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "DeleteOneTool", "删除一个Tool")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(toolId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(toolId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.SelectOne
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) SelectOne(user *global.User, toolId string) (*model.Tool, error) {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "SelectOneTool", "查询一个Tool")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(toolId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.UpdateOne
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) UpdateOne(user *global.User, entity *model.Tool) error {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "UpdateOneTool", "修改一个Tool")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ToolId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.Insert
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) Insert(user *global.User, entities *[]model.Tool) error {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "InsertTool", "插入多个Tool")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ToolId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.Delete
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) Delete(user *global.User, entities *[]model.Tool) error {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "DeleteTool", "删除多个Tool")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ToolId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.Select
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Tool, error) {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "SelectTool", "查询Tool")

	condition := DefaultConditionOfToolAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "SelectTool", "查询Tool")

	condition := DefaultConditionOfToolAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolService.Update
 *
 ******************************************************************************/
func (impl *ToolServiceImplement) Update(user *global.User, entities *[]model.Tool) error {

	grmi.Log(user, "/services/base/implments/Tool.service.impl.go", "UpdateTool", "修改多个Tool")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ToolId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
