// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : ToolGrp的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfToolGrp = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ToolGrp_ToolGrpId.UrlParameterName:                grmi.NewConditionItem(meta.ToolGrp_ToolGrpId, grmi.Equal, true),
		meta.ToolGrp_Descr.UrlParameterName:                    grmi.NewConditionItem(meta.ToolGrp_Descr, grmi.Equal, false),
		meta.ToolGrp_ProjectId.UrlParameterName:                grmi.NewConditionItem(meta.ToolGrp_ProjectId, grmi.Equal, false),
		meta.ToolGrp_ToolType.UrlParameterName:                 grmi.NewConditionItem(meta.ToolGrp_ToolType, grmi.Equal, false),
		meta.ToolGrp_Icon.UrlParameterName:                     grmi.NewConditionItem(meta.ToolGrp_Icon, grmi.Equal, false),
		meta.ToolGrp_Document.UrlParameterName:                 grmi.NewConditionItem(meta.ToolGrp_Document, grmi.Equal, false),
		meta.ToolGrp_CostRate.UrlParameterName:                 grmi.NewConditionItem(meta.ToolGrp_CostRate, grmi.Equal, false),
		meta.ToolGrp_CostCenterId.UrlParameterName:             grmi.NewConditionItem(meta.ToolGrp_CostCenterId, grmi.Equal, false),
		meta.ToolGrp_MaintenanceWay.UrlParameterName:           grmi.NewConditionItem(meta.ToolGrp_MaintenanceWay, grmi.Equal, false),
		meta.ToolGrp_LastMaintenanceDate.UrlParameterName:      grmi.NewConditionItem(meta.ToolGrp_LastMaintenanceDate, grmi.Approximate, false),
		meta.ToolGrp_MaintenanceCtrlValue.UrlParameterName:     grmi.NewConditionItem(meta.ToolGrp_MaintenanceCtrlValue, grmi.Equal, false),
		meta.ToolGrp_LastMaintenanceCtrlValue.UrlParameterName: grmi.NewConditionItem(meta.ToolGrp_LastMaintenanceCtrlValue, grmi.Equal, false),
		meta.ToolGrp_ExperationWay.UrlParameterName:            grmi.NewConditionItem(meta.ToolGrp_ExperationWay, grmi.Equal, false),
		meta.ToolGrp_ExperationDate.UrlParameterName:           grmi.NewConditionItem(meta.ToolGrp_ExperationDate, grmi.Approximate, false),
		meta.ToolGrp_ExperationCtrlValue.UrlParameterName:      grmi.NewConditionItem(meta.ToolGrp_ExperationCtrlValue, grmi.Equal, false),
		meta.ToolGrp_LastExperationCtrlValue.UrlParameterName:  grmi.NewConditionItem(meta.ToolGrp_LastExperationCtrlValue, grmi.Equal, false),
		meta.ToolGrp_LastModify.UrlParameterName:               grmi.NewConditionItem(meta.ToolGrp_LastModify, grmi.Approximate, false),
		meta.ToolGrp_LastUser.UrlParameterName:                 grmi.NewConditionItem(meta.ToolGrp_LastUser, grmi.Equal, false),
		meta.ToolGrp_CreateTime.UrlParameterName:               grmi.NewConditionItem(meta.ToolGrp_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ToolGrp的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfToolGrpAndPaging = grmi.NewCondition(
	DefaultConditionOfToolGrp.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ToolGrpServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ToolGrp的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type ToolGrpServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewToolGrpDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ToolGrpDAOImplement实例
 *
 * @Return Value             : ToolGrpDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewToolGrpServiceImplement() *ToolGrpServiceImplement {
	return &ToolGrpServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.InsertOne
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) InsertOne(user *global.User, entity *model.ToolGrp) error {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "InsertOneToolGrp", "插入一个ToolGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ToolGrpId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.DeleteOne
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) DeleteOne(user *global.User, toolGrpId string) error {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "DeleteOneToolGrp", "删除一个ToolGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(toolGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(toolGrpId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.SelectOne
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) SelectOne(user *global.User, toolGrpId string) (*model.ToolGrp, error) {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "SelectOneToolGrp", "查询一个ToolGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(toolGrpId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.UpdateOne
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) UpdateOne(user *global.User, entity *model.ToolGrp) error {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "UpdateOneToolGrp", "修改一个ToolGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ToolGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.Insert
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) Insert(user *global.User, entities *[]model.ToolGrp) error {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "InsertToolGrp", "插入多个ToolGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ToolGrpId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.Delete
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) Delete(user *global.User, entities *[]model.ToolGrp) error {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "DeleteToolGrp", "删除多个ToolGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ToolGrpId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.Select
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.ToolGrp, error) {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "SelectToolGrp", "查询ToolGrp")

	condition := DefaultConditionOfToolGrpAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "SelectToolGrp", "查询ToolGrp")

	condition := DefaultConditionOfToolGrpAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/ToolGrpService.Update
 *
 ******************************************************************************/
func (impl *ToolGrpServiceImplement) Update(user *global.User, entities *[]model.ToolGrp) error {

	grmi.Log(user, "/services/base/implments/ToolGrp.service.impl.go", "UpdateToolGrp", "修改多个ToolGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewToolGrpDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ToolGrpId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
