// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : WeekModel的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWeekModel = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WeekModel_WeekModelNr.UrlParameterName: grmi.NewConditionItem(meta.WeekModel_WeekModelNr, grmi.Equal, true),
		meta.WeekModel_DateFrom.UrlParameterName:    grmi.NewConditionItem(meta.WeekModel_DateFrom, grmi.Equal, false),
		meta.WeekModel_Descr.UrlParameterName:       grmi.NewConditionItem(meta.WeekModel_Descr, grmi.Equal, false),
		meta.WeekModel_Abrev.UrlParameterName:       grmi.NewConditionItem(meta.WeekModel_Abrev, grmi.Equal, false),
		meta.WeekModel_CtrlToggle.UrlParameterName:  grmi.NewConditionItem(meta.WeekModel_CtrlToggle, grmi.Equal, false),
		meta.WeekModel_LoopDays.UrlParameterName:    grmi.NewConditionItem(meta.WeekModel_LoopDays, grmi.Equal, false),
		meta.WeekModel_LastModify.UrlParameterName:  grmi.NewConditionItem(meta.WeekModel_LastModify, grmi.Approximate, false),
		meta.WeekModel_LastUser.UrlParameterName:    grmi.NewConditionItem(meta.WeekModel_LastUser, grmi.Equal, false),
		meta.WeekModel_CreateTime.UrlParameterName:  grmi.NewConditionItem(meta.WeekModel_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WeekModel的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWeekModelAndPaging = grmi.NewCondition(
	DefaultConditionOfWeekModel.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WeekModelServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WeekModel的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WeekModelServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWeekModelDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WeekModelDAOImplement实例
 *
 * @Return Value             : WeekModelDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWeekModelServiceImplement() *WeekModelServiceImplement {
	return &WeekModelServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.InsertOne
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) InsertOne(user *global.User, entity *model.WeekModel) error {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "InsertOneWeekModel", "插入一个WeekModel")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WeekModelNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.DeleteOne
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) DeleteOne(user *global.User, weekModelNr int) error {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "DeleteOneWeekModel", "删除一个WeekModel")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(weekModelNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(weekModelNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.SelectOne
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) SelectOne(user *global.User, weekModelNr int) (*model.WeekModel, error) {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "SelectOneWeekModel", "查询一个WeekModel")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(weekModelNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.UpdateOne
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) UpdateOne(user *global.User, entity *model.WeekModel) error {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "UpdateOneWeekModel", "修改一个WeekModel")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WeekModelNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.Insert
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) Insert(user *global.User, entities *[]model.WeekModel) error {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "InsertWeekModel", "插入多个WeekModel")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WeekModelNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.Delete
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) Delete(user *global.User, entities *[]model.WeekModel) error {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "DeleteWeekModel", "删除多个WeekModel")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WeekModelNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.Select
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WeekModel, error) {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "SelectWeekModel", "查询WeekModel")

	condition := DefaultConditionOfWeekModelAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "SelectWeekModel", "查询WeekModel")

	condition := DefaultConditionOfWeekModelAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WeekModelService.Update
 *
 ******************************************************************************/
func (impl *WeekModelServiceImplement) Update(user *global.User, entities *[]model.WeekModel) error {

	grmi.Log(user, "/services/base/implments/WeekModel.service.impl.go", "UpdateWeekModel", "修改多个WeekModel")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWeekModelDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WeekModelNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
