// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : WorkCalendar的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkCalendar = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkCalendar_WorkCalendarNr.UrlParameterName: grmi.NewConditionItem(meta.WorkCalendar_WorkCalendarNr, grmi.Equal, true),
		meta.WorkCalendar_Descr.UrlParameterName:          grmi.NewConditionItem(meta.WorkCalendar_Descr, grmi.Equal, false),
		meta.WorkCalendar_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendar_LastModify, grmi.Approximate, false),
		meta.WorkCalendar_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.WorkCalendar_LastUser, grmi.Equal, false),
		meta.WorkCalendar_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendar_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkCalendar的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkCalendarAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkCalendar.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WorkCalendarServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkCalendar的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WorkCalendarServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkCalendarDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkCalendarDAOImplement实例
 *
 * @Return Value             : WorkCalendarDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWorkCalendarServiceImplement() *WorkCalendarServiceImplement {
	return &WorkCalendarServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) InsertOne(user *global.User, entity *model.WorkCalendar) error {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "InsertOneWorkCalendar", "插入一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkCalendarNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) DeleteOne(user *global.User, workCalendarNr int) error {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "DeleteOneWorkCalendar", "删除一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(workCalendarNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workCalendarNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) SelectOne(user *global.User, workCalendarNr int) (*model.WorkCalendar, error) {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "SelectOneWorkCalendar", "查询一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(workCalendarNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) UpdateOne(user *global.User, entity *model.WorkCalendar) error {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "UpdateOneWorkCalendar", "修改一个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkCalendarNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.Insert
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) Insert(user *global.User, entities *[]model.WorkCalendar) error {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "InsertWorkCalendar", "插入多个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkCalendarNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.Delete
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) Delete(user *global.User, entities *[]model.WorkCalendar) error {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "DeleteWorkCalendar", "删除多个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkCalendarNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.Select
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WorkCalendar, error) {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "SelectWorkCalendar", "查询WorkCalendar")

	condition := DefaultConditionOfWorkCalendarAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "SelectWorkCalendar", "查询WorkCalendar")

	condition := DefaultConditionOfWorkCalendarAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarService.Update
 *
 ******************************************************************************/
func (impl *WorkCalendarServiceImplement) Update(user *global.User, entities *[]model.WorkCalendar) error {

	grmi.Log(user, "/services/base/implments/WorkCalendar.service.impl.go", "UpdateWorkCalendar", "修改多个WorkCalendar")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkCalendarNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
