// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : WorkCalendarLst的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkCalendarLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkCalendarLst_WorkCalendarNr.UrlParameterName: grmi.NewConditionItem(meta.WorkCalendarLst_WorkCalendarNr, grmi.Equal, true),
		meta.WorkCalendarLst_WorkDate.UrlParameterName:       grmi.NewConditionItem(meta.WorkCalendarLst_WorkDate, grmi.Equal, true),
		meta.WorkCalendarLst_DayModelNr.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendarLst_DayModelNr, grmi.Equal, false),
		meta.WorkCalendarLst_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendarLst_LastModify, grmi.Approximate, false),
		meta.WorkCalendarLst_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.WorkCalendarLst_LastUser, grmi.Equal, false),
		meta.WorkCalendarLst_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.WorkCalendarLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkCalendarLst的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkCalendarLstAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkCalendarLst.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WorkCalendarLstServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkCalendarLst的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WorkCalendarLstServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkCalendarLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkCalendarLstDAOImplement实例
 *
 * @Return Value             : WorkCalendarLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWorkCalendarLstServiceImplement() *WorkCalendarLstServiceImplement {
	return &WorkCalendarLstServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) InsertOne(user *global.User, entity *model.WorkCalendarLst) error {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "InsertOneWorkCalendarLst", "插入一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkCalendarNr, entity.WorkDate)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) DeleteOne(user *global.User, workCalendarNr int, workDate string) error {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "DeleteOneWorkCalendarLst", "删除一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(workCalendarNr, workDate)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workCalendarNr, workDate)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) SelectOne(user *global.User, workCalendarNr int, workDate string) (*model.WorkCalendarLst, error) {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "SelectOneWorkCalendarLst", "查询一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(workCalendarNr, workDate)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) UpdateOne(user *global.User, entity *model.WorkCalendarLst) error {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "UpdateOneWorkCalendarLst", "修改一个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkCalendarNr, entity.WorkDate)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.Insert
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) Insert(user *global.User, entities *[]model.WorkCalendarLst) error {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "InsertWorkCalendarLst", "插入多个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkCalendarNr, entity.WorkDate)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.Delete
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) Delete(user *global.User, entities *[]model.WorkCalendarLst) error {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "DeleteWorkCalendarLst", "删除多个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkCalendarNr, entity.WorkDate)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.Select
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WorkCalendarLst, error) {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "SelectWorkCalendarLst", "查询WorkCalendarLst")

	condition := DefaultConditionOfWorkCalendarLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "SelectWorkCalendarLst", "查询WorkCalendarLst")

	condition := DefaultConditionOfWorkCalendarLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkCalendarLstService.Update
 *
 ******************************************************************************/
func (impl *WorkCalendarLstServiceImplement) Update(user *global.User, entities *[]model.WorkCalendarLst) error {

	grmi.Log(user, "/services/base/implments/WorkCalendarLst.service.impl.go", "UpdateWorkCalendarLst", "修改多个WorkCalendarLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkCalendarLstDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkCalendarNr, entity.WorkDate)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
