// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : WorkPlaceGrp的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkPlaceGrp = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkPlaceGrp_WorkPlaceGrpId.UrlParameterName: grmi.NewConditionItem(meta.WorkPlaceGrp_WorkPlaceGrpId, grmi.Equal, true),
		meta.WorkPlaceGrp_Descr.UrlParameterName:          grmi.NewConditionItem(meta.WorkPlaceGrp_Descr, grmi.Equal, false),
		meta.WorkPlaceGrp_WorkPlaceType.UrlParameterName:  grmi.NewConditionItem(meta.WorkPlaceGrp_WorkPlaceType, grmi.Equal, false),
		meta.WorkPlaceGrp_CapacityType.UrlParameterName:   grmi.NewConditionItem(meta.WorkPlaceGrp_CapacityType, grmi.Equal, false),
		meta.WorkPlaceGrp_CapacityFactor.UrlParameterName: grmi.NewConditionItem(meta.WorkPlaceGrp_CapacityFactor, grmi.Equal, false),
		meta.WorkPlaceGrp_PlanEfficiency.UrlParameterName: grmi.NewConditionItem(meta.WorkPlaceGrp_PlanEfficiency, grmi.Equal, false),
		meta.WorkPlaceGrp_CostRate.UrlParameterName:       grmi.NewConditionItem(meta.WorkPlaceGrp_CostRate, grmi.Equal, false),
		meta.WorkPlaceGrp_WeekModelNr.UrlParameterName:    grmi.NewConditionItem(meta.WorkPlaceGrp_WeekModelNr, grmi.Equal, false),
		meta.WorkPlaceGrp_WorkCalendarNr.UrlParameterName: grmi.NewConditionItem(meta.WorkPlaceGrp_WorkCalendarNr, grmi.Equal, false),
		meta.WorkPlaceGrp_CostCenterId.UrlParameterName:   grmi.NewConditionItem(meta.WorkPlaceGrp_CostCenterId, grmi.Equal, false),
		meta.WorkPlaceGrp_LocationId.UrlParameterName:     grmi.NewConditionItem(meta.WorkPlaceGrp_LocationId, grmi.Equal, false),
		meta.WorkPlaceGrp_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.WorkPlaceGrp_LastModify, grmi.Approximate, false),
		meta.WorkPlaceGrp_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.WorkPlaceGrp_LastUser, grmi.Equal, false),
		meta.WorkPlaceGrp_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.WorkPlaceGrp_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkPlaceGrp的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkPlaceGrpAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkPlaceGrp.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WorkPlaceGrpServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkPlaceGrp的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WorkPlaceGrpServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkPlaceGrpDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkPlaceGrpDAOImplement实例
 *
 * @Return Value             : WorkPlaceGrpDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWorkPlaceGrpServiceImplement() *WorkPlaceGrpServiceImplement {
	return &WorkPlaceGrpServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) InsertOne(user *global.User, entity *model.WorkPlaceGrp) error {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "InsertOneWorkPlaceGrp", "插入一个WorkPlaceGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkPlaceGrpId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) DeleteOne(user *global.User, workPlaceGrpId string) error {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "DeleteOneWorkPlaceGrp", "删除一个WorkPlaceGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(workPlaceGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workPlaceGrpId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) SelectOne(user *global.User, workPlaceGrpId string) (*model.WorkPlaceGrp, error) {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "SelectOneWorkPlaceGrp", "查询一个WorkPlaceGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(workPlaceGrpId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) UpdateOne(user *global.User, entity *model.WorkPlaceGrp) error {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "UpdateOneWorkPlaceGrp", "修改一个WorkPlaceGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkPlaceGrpId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.Insert
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) Insert(user *global.User, entities *[]model.WorkPlaceGrp) error {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "InsertWorkPlaceGrp", "插入多个WorkPlaceGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkPlaceGrpId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.Delete
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) Delete(user *global.User, entities *[]model.WorkPlaceGrp) error {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "DeleteWorkPlaceGrp", "删除多个WorkPlaceGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkPlaceGrpId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.Select
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WorkPlaceGrp, error) {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "SelectWorkPlaceGrp", "查询WorkPlaceGrp")

	condition := DefaultConditionOfWorkPlaceGrpAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "SelectWorkPlaceGrp", "查询WorkPlaceGrp")

	condition := DefaultConditionOfWorkPlaceGrpAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkPlaceGrpService.Update
 *
 ******************************************************************************/
func (impl *WorkPlaceGrpServiceImplement) Update(user *global.User, entities *[]model.WorkPlaceGrp) error {

	grmi.Log(user, "/services/base/implments/WorkPlaceGrp.service.impl.go", "UpdateWorkPlaceGrp", "修改多个WorkPlaceGrp")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkPlaceGrpDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkPlaceGrpId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
