// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/base"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/base"
	model "LAPP_AS/models/base"
)

/******************************************************************************
 *
 * @Description              : WorkShift的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkShift = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkShift_WorkShiftNr.UrlParameterName:    grmi.NewConditionItem(meta.WorkShift_WorkShiftNr, grmi.Equal, true),
		meta.WorkShift_Descr.UrlParameterName:          grmi.NewConditionItem(meta.WorkShift_Descr, grmi.Equal, false),
		meta.WorkShift_Abrev.UrlParameterName:          grmi.NewConditionItem(meta.WorkShift_Abrev, grmi.Equal, false),
		meta.WorkShift_HexColor.UrlParameterName:       grmi.NewConditionItem(meta.WorkShift_HexColor, grmi.Equal, false),
		meta.WorkShift_PlanPersonQty.UrlParameterName:  grmi.NewConditionItem(meta.WorkShift_PlanPersonQty, grmi.Equal, false),
		meta.WorkShift_PlanEfficiency.UrlParameterName: grmi.NewConditionItem(meta.WorkShift_PlanEfficiency, grmi.Equal, false),
		meta.WorkShift_SBeg.UrlParameterName:           grmi.NewConditionItem(meta.WorkShift_SBeg, grmi.Equal, false),
		meta.WorkShift_SEnd.UrlParameterName:           grmi.NewConditionItem(meta.WorkShift_SEnd, grmi.Equal, false),
		meta.WorkShift_SLen.UrlParameterName:           grmi.NewConditionItem(meta.WorkShift_SLen, grmi.Equal, false),
		meta.WorkShift_SB1Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB1Beg, grmi.Equal, false),
		meta.WorkShift_SB1End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB1End, grmi.Equal, false),
		meta.WorkShift_SB2Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB2Beg, grmi.Equal, false),
		meta.WorkShift_SB2End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB2End, grmi.Equal, false),
		meta.WorkShift_SB3Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB3Beg, grmi.Equal, false),
		meta.WorkShift_SB3End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB3End, grmi.Equal, false),
		meta.WorkShift_SB4Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB4Beg, grmi.Equal, false),
		meta.WorkShift_SB4End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB4End, grmi.Equal, false),
		meta.WorkShift_SB5Beg.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB5Beg, grmi.Equal, false),
		meta.WorkShift_SB5End.UrlParameterName:         grmi.NewConditionItem(meta.WorkShift_SB5End, grmi.Equal, false),
		meta.WorkShift_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.WorkShift_LastModify, grmi.Approximate, false),
		meta.WorkShift_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.WorkShift_LastUser, grmi.Equal, false),
		meta.WorkShift_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.WorkShift_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkShift的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkShiftAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkShift.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WorkShiftServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkShift的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WorkShiftServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkShiftDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkShiftDAOImplement实例
 *
 * @Return Value             : WorkShiftDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWorkShiftServiceImplement() *WorkShiftServiceImplement {
	return &WorkShiftServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) InsertOne(user *global.User, entity *model.WorkShift) error {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "InsertOneWorkShift", "插入一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkShiftNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) DeleteOne(user *global.User, workShiftNr int) error {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "DeleteOneWorkShift", "删除一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(workShiftNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workShiftNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) SelectOne(user *global.User, workShiftNr int) (*model.WorkShift, error) {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "SelectOneWorkShift", "查询一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(workShiftNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) UpdateOne(user *global.User, entity *model.WorkShift) error {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "UpdateOneWorkShift", "修改一个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkShiftNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.Insert
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) Insert(user *global.User, entities *[]model.WorkShift) error {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "InsertWorkShift", "插入多个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkShiftNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.Delete
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) Delete(user *global.User, entities *[]model.WorkShift) error {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "DeleteWorkShift", "删除多个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkShiftNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.Select
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WorkShift, error) {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "SelectWorkShift", "查询WorkShift")

	condition := DefaultConditionOfWorkShiftAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "SelectWorkShift", "查询WorkShift")

	condition := DefaultConditionOfWorkShiftAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/base/WorkShiftService.Update
 *
 ******************************************************************************/
func (impl *WorkShiftServiceImplement) Update(user *global.User, entities *[]model.WorkShift) error {

	grmi.Log(user, "/services/base/implments/WorkShift.service.impl.go", "UpdateWorkShift", "修改多个WorkShift")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkShiftDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkShiftNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
