// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/om"
	"LAPP_AS/services/om/implments"
)

/******************************************************************************
 *
 * @Interface Name           : WOOperationService
 *-----------------------------------------------------------------------------
 *
 * @Description              : WOOperation的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WOOperationService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条WOOperation
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WOOperation
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.WOOperation) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的WOOperation
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, string, int, int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WOOperation
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WOOperation
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	SelectOne(*global.User, string, int, int) (*model.WOOperation, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条WOOperation
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WOOperation
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.WOOperation) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条WOOperation
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WOOperation列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.WOOperation) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条WOOperation
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的WOOperation列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.WOOperation) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询WOOperation
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.WOOperation, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询WOOperation
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条WOOperation
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WOOperation列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 14:06:46
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.WOOperation) error
}

/******************************************************************************
 *
 * @Function Name            : NewWOOperationService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WOOperationService
 *
 * @Return Value             : WOOperationService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWOOperationService() WOOperationService {
	return implments.NewWOOperationServiceImplement()
}
