// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/om"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/om"
	model "LAPP_AS/models/om"
)

/******************************************************************************
 *
 * @Description              : OrderNetWork的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfOrderNetWork = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.OrderNetWork_WorkOrderId.UrlParameterName:          grmi.NewConditionItem(meta.OrderNetWork_WorkOrderId, grmi.Equal, true),
		meta.OrderNetWork_OperationNr.UrlParameterName:          grmi.NewConditionItem(meta.OrderNetWork_OperationNr, grmi.Equal, true),
		meta.OrderNetWork_SplitNr.UrlParameterName:              grmi.NewConditionItem(meta.OrderNetWork_SplitNr, grmi.Equal, true),
		meta.OrderNetWork_PrevWorkOrderId.UrlParameterName:      grmi.NewConditionItem(meta.OrderNetWork_PrevWorkOrderId, grmi.Equal, true),
		meta.OrderNetWork_PrevOperationNr.UrlParameterName:      grmi.NewConditionItem(meta.OrderNetWork_PrevOperationNr, grmi.Equal, true),
		meta.OrderNetWork_PrevSplitNr.UrlParameterName:          grmi.NewConditionItem(meta.OrderNetWork_PrevSplitNr, grmi.Equal, true),
		meta.OrderNetWork_Qty.UrlParameterName:                  grmi.NewConditionItem(meta.OrderNetWork_Qty, grmi.Equal, false),
		meta.OrderNetWork_PrevQty.UrlParameterName:              grmi.NewConditionItem(meta.OrderNetWork_PrevQty, grmi.Equal, false),
		meta.OrderNetWork_SetupDuration.UrlParameterName:        grmi.NewConditionItem(meta.OrderNetWork_SetupDuration, grmi.Equal, false),
		meta.OrderNetWork_DurationUomId.UrlParameterName:        grmi.NewConditionItem(meta.OrderNetWork_DurationUomId, grmi.Equal, false),
		meta.OrderNetWork_ProjectId.UrlParameterName:            grmi.NewConditionItem(meta.OrderNetWork_ProjectId, grmi.Equal, false),
		meta.OrderNetWork_IsCriticalPathToggle.UrlParameterName: grmi.NewConditionItem(meta.OrderNetWork_IsCriticalPathToggle, grmi.Equal, false),
		meta.OrderNetWork_CtrlPara1.UrlParameterName:            grmi.NewConditionItem(meta.OrderNetWork_CtrlPara1, grmi.Equal, false),
		meta.OrderNetWork_CtrlPara2.UrlParameterName:            grmi.NewConditionItem(meta.OrderNetWork_CtrlPara2, grmi.Equal, false),
		meta.OrderNetWork_CtrlStr1.UrlParameterName:             grmi.NewConditionItem(meta.OrderNetWork_CtrlStr1, grmi.Equal, false),
		meta.OrderNetWork_CtrlStr2.UrlParameterName:             grmi.NewConditionItem(meta.OrderNetWork_CtrlStr2, grmi.Equal, false),
		meta.OrderNetWork_LastModify.UrlParameterName:           grmi.NewConditionItem(meta.OrderNetWork_LastModify, grmi.Approximate, false),
		meta.OrderNetWork_LastUser.UrlParameterName:             grmi.NewConditionItem(meta.OrderNetWork_LastUser, grmi.Equal, false),
		meta.OrderNetWork_CreateTime.UrlParameterName:           grmi.NewConditionItem(meta.OrderNetWork_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : OrderNetWork的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfOrderNetWorkAndPaging = grmi.NewCondition(
	DefaultConditionOfOrderNetWork.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : OrderNetWorkServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : OrderNetWork的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type OrderNetWorkServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewOrderNetWorkDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个OrderNetWorkDAOImplement实例
 *
 * @Return Value             : OrderNetWorkDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewOrderNetWorkServiceImplement() *OrderNetWorkServiceImplement {
	return &OrderNetWorkServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.InsertOne
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) InsertOne(user *global.User, entity *model.OrderNetWork) error {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "InsertOneOrderNetWork", "插入一个OrderNetWork")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr, entity.PrevWorkOrderId, entity.PrevOperationNr, entity.PrevSplitNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.DeleteOne
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) DeleteOne(user *global.User, workOrderId string, operationNr int, splitNr int, prevWorkOrderId string, prevOperationNr int, prevSplitNr int) error {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "DeleteOneOrderNetWork", "删除一个OrderNetWork")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(workOrderId, operationNr, splitNr, prevWorkOrderId, prevOperationNr, prevSplitNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workOrderId, operationNr, splitNr, prevWorkOrderId, prevOperationNr, prevSplitNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.SelectOne
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) SelectOne(user *global.User, workOrderId string, operationNr int, splitNr int, prevWorkOrderId string, prevOperationNr int, prevSplitNr int) (*model.OrderNetWork, error) {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "SelectOneOrderNetWork", "查询一个OrderNetWork")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(workOrderId, operationNr, splitNr, prevWorkOrderId, prevOperationNr, prevSplitNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.UpdateOne
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) UpdateOne(user *global.User, entity *model.OrderNetWork) error {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "UpdateOneOrderNetWork", "修改一个OrderNetWork")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr, entity.PrevWorkOrderId, entity.PrevOperationNr, entity.PrevSplitNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.Insert
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) Insert(user *global.User, entities *[]model.OrderNetWork) error {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "InsertOrderNetWork", "插入多个OrderNetWork")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr, entity.PrevWorkOrderId, entity.PrevOperationNr, entity.PrevSplitNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.Delete
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) Delete(user *global.User, entities *[]model.OrderNetWork) error {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "DeleteOrderNetWork", "删除多个OrderNetWork")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr, entity.PrevWorkOrderId, entity.PrevOperationNr, entity.PrevSplitNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.Select
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.OrderNetWork, error) {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "SelectOrderNetWork", "查询OrderNetWork")

	condition := DefaultConditionOfOrderNetWorkAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "SelectOrderNetWork", "查询OrderNetWork")

	condition := DefaultConditionOfOrderNetWorkAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/OrderNetWorkService.Update
 *
 ******************************************************************************/
func (impl *OrderNetWorkServiceImplement) Update(user *global.User, entities *[]model.OrderNetWork) error {

	grmi.Log(user, "/services/om/implments/OrderNetWork.service.impl.go", "UpdateOrderNetWork", "修改多个OrderNetWork")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOrderNetWorkDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr, entity.PrevWorkOrderId, entity.PrevOperationNr, entity.PrevSplitNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
