// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/om"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/om"
	model "LAPP_AS/models/om"
)

/******************************************************************************
 *
 * @Description              : WOOperationStatus的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWOOperationStatus = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WOOperationStatus_WorkOrderId.UrlParameterName:        grmi.NewConditionItem(meta.WOOperationStatus_WorkOrderId, grmi.Equal, true),
		meta.WOOperationStatus_OperationNr.UrlParameterName:        grmi.NewConditionItem(meta.WOOperationStatus_OperationNr, grmi.Equal, true),
		meta.WOOperationStatus_SplitNr.UrlParameterName:            grmi.NewConditionItem(meta.WOOperationStatus_SplitNr, grmi.Equal, true),
		meta.WOOperationStatus_Status.UrlParameterName:             grmi.NewConditionItem(meta.WOOperationStatus_Status, grmi.Equal, false),
		meta.WOOperationStatus_TriggerEvent.UrlParameterName:       grmi.NewConditionItem(meta.WOOperationStatus_TriggerEvent, grmi.Equal, false),
		meta.WOOperationStatus_TriggerObjectId.UrlParameterName:    grmi.NewConditionItem(meta.WOOperationStatus_TriggerObjectId, grmi.Equal, false),
		meta.WOOperationStatus_TriggerSubObjectId.UrlParameterName: grmi.NewConditionItem(meta.WOOperationStatus_TriggerSubObjectId, grmi.Equal, false),
		meta.WOOperationStatus_LastModify.UrlParameterName:         grmi.NewConditionItem(meta.WOOperationStatus_LastModify, grmi.Approximate, false),
		meta.WOOperationStatus_LastUser.UrlParameterName:           grmi.NewConditionItem(meta.WOOperationStatus_LastUser, grmi.Equal, false),
		meta.WOOperationStatus_CreateTime.UrlParameterName:         grmi.NewConditionItem(meta.WOOperationStatus_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WOOperationStatus的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWOOperationStatusAndPaging = grmi.NewCondition(
	DefaultConditionOfWOOperationStatus.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WOOperationStatusServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WOOperationStatus的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WOOperationStatusServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWOOperationStatusDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WOOperationStatusDAOImplement实例
 *
 * @Return Value             : WOOperationStatusDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWOOperationStatusServiceImplement() *WOOperationStatusServiceImplement {
	return &WOOperationStatusServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.InsertOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) InsertOne(user *global.User, entity *model.WOOperationStatus) error {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "InsertOneWOOperationStatus", "插入一个WOOperationStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.DeleteOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) DeleteOne(user *global.User, workOrderId string, operationNr int, splitNr int) error {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "DeleteOneWOOperationStatus", "删除一个WOOperationStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(workOrderId, operationNr, splitNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workOrderId, operationNr, splitNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.SelectOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) SelectOne(user *global.User, workOrderId string, operationNr int, splitNr int) (*model.WOOperationStatus, error) {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "SelectOneWOOperationStatus", "查询一个WOOperationStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(workOrderId, operationNr, splitNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.UpdateOne
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) UpdateOne(user *global.User, entity *model.WOOperationStatus) error {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "UpdateOneWOOperationStatus", "修改一个WOOperationStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.Insert
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) Insert(user *global.User, entities *[]model.WOOperationStatus) error {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "InsertWOOperationStatus", "插入多个WOOperationStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.Delete
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) Delete(user *global.User, entities *[]model.WOOperationStatus) error {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "DeleteWOOperationStatus", "删除多个WOOperationStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.Select
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WOOperationStatus, error) {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "SelectWOOperationStatus", "查询WOOperationStatus")

	condition := DefaultConditionOfWOOperationStatusAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "SelectWOOperationStatus", "查询WOOperationStatus")

	condition := DefaultConditionOfWOOperationStatusAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WOOperationStatusService.Update
 *
 ******************************************************************************/
func (impl *WOOperationStatusServiceImplement) Update(user *global.User, entities *[]model.WOOperationStatus) error {

	grmi.Log(user, "/services/om/implments/WOOperationStatus.service.impl.go", "UpdateWOOperationStatus", "修改多个WOOperationStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWOOperationStatusDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId, entity.OperationNr, entity.SplitNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
