// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/om"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/om"
	model "LAPP_AS/models/om"
)

/******************************************************************************
 *
 * @Description              : WorkOrderStatus的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkOrderStatus = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkOrderStatus_WorkOrderId.UrlParameterName:        grmi.NewConditionItem(meta.WorkOrderStatus_WorkOrderId, grmi.Equal, true),
		meta.WorkOrderStatus_Status.UrlParameterName:             grmi.NewConditionItem(meta.WorkOrderStatus_Status, grmi.Equal, false),
		meta.WorkOrderStatus_TriggerEvent.UrlParameterName:       grmi.NewConditionItem(meta.WorkOrderStatus_TriggerEvent, grmi.Equal, false),
		meta.WorkOrderStatus_TriggerObjectId.UrlParameterName:    grmi.NewConditionItem(meta.WorkOrderStatus_TriggerObjectId, grmi.Equal, false),
		meta.WorkOrderStatus_TriggerSubObjectId.UrlParameterName: grmi.NewConditionItem(meta.WorkOrderStatus_TriggerSubObjectId, grmi.Equal, false),
		meta.WorkOrderStatus_LastModify.UrlParameterName:         grmi.NewConditionItem(meta.WorkOrderStatus_LastModify, grmi.Approximate, false),
		meta.WorkOrderStatus_LastUser.UrlParameterName:           grmi.NewConditionItem(meta.WorkOrderStatus_LastUser, grmi.Equal, false),
		meta.WorkOrderStatus_CreateTime.UrlParameterName:         grmi.NewConditionItem(meta.WorkOrderStatus_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkOrderStatus的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfWorkOrderStatusAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkOrderStatus.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : WorkOrderStatusServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkOrderStatus的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type WorkOrderStatusServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkOrderStatusDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkOrderStatusDAOImplement实例
 *
 * @Return Value             : WorkOrderStatusDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewWorkOrderStatusServiceImplement() *WorkOrderStatusServiceImplement {
	return &WorkOrderStatusServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) InsertOne(user *global.User, entity *model.WorkOrderStatus) error {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "InsertOneWorkOrderStatus", "插入一个WorkOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkOrderId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) DeleteOne(user *global.User, workOrderId string) error {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "DeleteOneWorkOrderStatus", "删除一个WorkOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(workOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workOrderId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) SelectOne(user *global.User, workOrderId string) (*model.WorkOrderStatus, error) {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "SelectOneWorkOrderStatus", "查询一个WorkOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(workOrderId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) UpdateOne(user *global.User, entity *model.WorkOrderStatus) error {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "UpdateOneWorkOrderStatus", "修改一个WorkOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.WorkOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.Insert
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) Insert(user *global.User, entities *[]model.WorkOrderStatus) error {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "InsertWorkOrderStatus", "插入多个WorkOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.Delete
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) Delete(user *global.User, entities *[]model.WorkOrderStatus) error {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "DeleteWorkOrderStatus", "删除多个WorkOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.Select
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.WorkOrderStatus, error) {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "SelectWorkOrderStatus", "查询WorkOrderStatus")

	condition := DefaultConditionOfWorkOrderStatusAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "SelectWorkOrderStatus", "查询WorkOrderStatus")

	condition := DefaultConditionOfWorkOrderStatusAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/om/WorkOrderStatusService.Update
 *
 ******************************************************************************/
func (impl *WorkOrderStatusServiceImplement) Update(user *global.User, entities *[]model.WorkOrderStatus) error {

	grmi.Log(user, "/services/om/implments/WorkOrderStatus.service.impl.go", "UpdateWorkOrderStatus", "修改多个WorkOrderStatus")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkOrderStatusDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkOrderId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
