// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/pdc"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/pdc"
	model "LAPP_AS/models/pdc"
)

/******************************************************************************
 *
 * @Description              : ReportRecord的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfReportRecord = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ReportRecord_RecordNr.UrlParameterName:       grmi.NewConditionItem(meta.ReportRecord_RecordNr, grmi.Equal, true),
		meta.ReportRecord_LastRecordUser.UrlParameterName: grmi.NewConditionItem(meta.ReportRecord_LastRecordUser, grmi.Equal, false),
		meta.ReportRecord_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.ReportRecord_LastModify, grmi.Approximate, false),
		meta.ReportRecord_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.ReportRecord_LastUser, grmi.Equal, false),
		meta.ReportRecord_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.ReportRecord_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ReportRecord的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfReportRecordAndPaging = grmi.NewCondition(
	DefaultConditionOfReportRecord.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ReportRecordServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ReportRecord的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type ReportRecordServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewReportRecordDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ReportRecordDAOImplement实例
 *
 * @Return Value             : ReportRecordDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewReportRecordServiceImplement() *ReportRecordServiceImplement {
	return &ReportRecordServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.InsertOne
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) InsertOne(user *global.User, entity *model.ReportRecord) error {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "InsertOneReportRecord", "插入一个ReportRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.RecordNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.DeleteOne
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) DeleteOne(user *global.User, recordNr int) error {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "DeleteOneReportRecord", "删除一个ReportRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(recordNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(recordNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.SelectOne
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) SelectOne(user *global.User, recordNr int) (*model.ReportRecord, error) {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "SelectOneReportRecord", "查询一个ReportRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(recordNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.UpdateOne
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) UpdateOne(user *global.User, entity *model.ReportRecord) error {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "UpdateOneReportRecord", "修改一个ReportRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.RecordNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.Insert
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) Insert(user *global.User, entities *[]model.ReportRecord) error {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "InsertReportRecord", "插入多个ReportRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RecordNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.Delete
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) Delete(user *global.User, entities *[]model.ReportRecord) error {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "DeleteReportRecord", "删除多个ReportRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RecordNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.Select
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.ReportRecord, error) {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "SelectReportRecord", "查询ReportRecord")

	condition := DefaultConditionOfReportRecordAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "SelectReportRecord", "查询ReportRecord")

	condition := DefaultConditionOfReportRecordAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/pdc/ReportRecordService.Update
 *
 ******************************************************************************/
func (impl *ReportRecordServiceImplement) Update(user *global.User, entities *[]model.ReportRecord) error {

	grmi.Log(user, "/services/pdc/implments/ReportRecord.service.impl.go", "UpdateReportRecord", "修改多个ReportRecord")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReportRecordDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RecordNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
