// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/wm"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/wm"
	model "LAPP_AS/models/wm"
)

/******************************************************************************
 *
 * @Description              : Stock的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfStock = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Stock_ArtId.UrlParameterName:                      grmi.NewConditionItem(meta.Stock_ArtId, grmi.Equal, true),
		meta.Stock_WarehouseNr.UrlParameterName:                grmi.NewConditionItem(meta.Stock_WarehouseNr, grmi.Equal, false),
		meta.Stock_Status.UrlParameterName:                     grmi.NewConditionItem(meta.Stock_Status, grmi.Equal, false),
		meta.Stock_ActStock.UrlParameterName:                   grmi.NewConditionItem(meta.Stock_ActStock, grmi.Equal, false),
		meta.Stock_PlanStock.UrlParameterName:                  grmi.NewConditionItem(meta.Stock_PlanStock, grmi.Equal, false),
		meta.Stock_ReservedStock.UrlParameterName:              grmi.NewConditionItem(meta.Stock_ReservedStock, grmi.Equal, false),
		meta.Stock_AvailableStock.UrlParameterName:             grmi.NewConditionItem(meta.Stock_AvailableStock, grmi.Equal, false),
		meta.Stock_CalculatedReorderPoint.UrlParameterName:     grmi.NewConditionItem(meta.Stock_CalculatedReorderPoint, grmi.Equal, false),
		meta.Stock_ManualOrderPoint.UrlParameterName:           grmi.NewConditionItem(meta.Stock_ManualOrderPoint, grmi.Equal, false),
		meta.Stock_CalculatedOptimumBatchSize.UrlParameterName: grmi.NewConditionItem(meta.Stock_CalculatedOptimumBatchSize, grmi.Equal, false),
		meta.Stock_ManualOptimumLotSize.UrlParameterName:       grmi.NewConditionItem(meta.Stock_ManualOptimumLotSize, grmi.Equal, false),
		meta.Stock_ManualOrderDate.UrlParameterName:            grmi.NewConditionItem(meta.Stock_ManualOrderDate, grmi.Approximate, false),
		meta.Stock_MainController.UrlParameterName:             grmi.NewConditionItem(meta.Stock_MainController, grmi.Equal, false),
		meta.Stock_ProdArtId.UrlParameterName:                  grmi.NewConditionItem(meta.Stock_ProdArtId, grmi.Equal, false),
		meta.Stock_ABCClass.UrlParameterName:                   grmi.NewConditionItem(meta.Stock_ABCClass, grmi.Equal, false),
		meta.Stock_QtyUomId.UrlParameterName:                   grmi.NewConditionItem(meta.Stock_QtyUomId, grmi.Equal, false),
		meta.Stock_ProcurementKeyNr.UrlParameterName:           grmi.NewConditionItem(meta.Stock_ProcurementKeyNr, grmi.Equal, false),
		meta.Stock_PurchaseGroupId.UrlParameterName:            grmi.NewConditionItem(meta.Stock_PurchaseGroupId, grmi.Equal, false),
		meta.Stock_LastModify.UrlParameterName:                 grmi.NewConditionItem(meta.Stock_LastModify, grmi.Approximate, false),
		meta.Stock_LastUser.UrlParameterName:                   grmi.NewConditionItem(meta.Stock_LastUser, grmi.Equal, false),
		meta.Stock_CreateTime.UrlParameterName:                 grmi.NewConditionItem(meta.Stock_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Stock的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfStockAndPaging = grmi.NewCondition(
	DefaultConditionOfStock.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : StockServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Stock的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type StockServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewStockDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个StockDAOImplement实例
 *
 * @Return Value             : StockDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewStockServiceImplement() *StockServiceImplement {
	return &StockServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.InsertOne
 *
 ******************************************************************************/
func (impl *StockServiceImplement) InsertOne(user *global.User, entity *model.Stock) error {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "InsertOneStock", "插入一个Stock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.DeleteOne
 *
 ******************************************************************************/
func (impl *StockServiceImplement) DeleteOne(user *global.User, artId string) error {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "DeleteOneStock", "删除一个Stock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(artId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.SelectOne
 *
 ******************************************************************************/
func (impl *StockServiceImplement) SelectOne(user *global.User, artId string) (*model.Stock, error) {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "SelectOneStock", "查询一个Stock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(artId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.UpdateOne
 *
 ******************************************************************************/
func (impl *StockServiceImplement) UpdateOne(user *global.User, entity *model.Stock) error {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "UpdateOneStock", "修改一个Stock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.Insert
 *
 ******************************************************************************/
func (impl *StockServiceImplement) Insert(user *global.User, entities *[]model.Stock) error {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "InsertStock", "插入多个Stock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.Delete
 *
 ******************************************************************************/
func (impl *StockServiceImplement) Delete(user *global.User, entities *[]model.Stock) error {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "DeleteStock", "删除多个Stock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.Select
 *
 ******************************************************************************/
func (impl *StockServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Stock, error) {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "SelectStock", "查询Stock")

	condition := DefaultConditionOfStockAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *StockServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "SelectStock", "查询Stock")

	condition := DefaultConditionOfStockAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/StockService.Update
 *
 ******************************************************************************/
func (impl *StockServiceImplement) Update(user *global.User, entities *[]model.Stock) error {

	grmi.Log(user, "/services/wm/implments/Stock.service.impl.go", "UpdateStock", "修改多个Stock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewStockDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
