// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_AS/dao/wm"
	"LAPP_AS/db"
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	meta "LAPP_AS/meta/wm"
	model "LAPP_AS/models/wm"
)

/******************************************************************************
 *
 * @Description              : TransitStock的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfTransitStock = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.TransitStock_ArtId.UrlParameterName:      grmi.NewConditionItem(meta.TransitStock_ArtId, grmi.Equal, true),
		meta.TransitStock_Pos.UrlParameterName:        grmi.NewConditionItem(meta.TransitStock_Pos, grmi.Equal, true),
		meta.TransitStock_OrderTime.UrlParameterName:  grmi.NewConditionItem(meta.TransitStock_OrderTime, grmi.Approximate, false),
		meta.TransitStock_ActStock.UrlParameterName:   grmi.NewConditionItem(meta.TransitStock_ActStock, grmi.Equal, false),
		meta.TransitStock_LastModify.UrlParameterName: grmi.NewConditionItem(meta.TransitStock_LastModify, grmi.Approximate, false),
		meta.TransitStock_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.TransitStock_LastUser, grmi.Equal, false),
		meta.TransitStock_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.TransitStock_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : TransitStock的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
var DefaultConditionOfTransitStockAndPaging = grmi.NewCondition(
	DefaultConditionOfTransitStock.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : TransitStockServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : TransitStock的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
type TransitStockServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewTransitStockDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个TransitStockDAOImplement实例
 *
 * @Return Value             : TransitStockDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func NewTransitStockServiceImplement() *TransitStockServiceImplement {
	return &TransitStockServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.InsertOne
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) InsertOne(user *global.User, entity *model.TransitStock) error {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "InsertOneTransitStock", "插入一个TransitStock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ArtId, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.DeleteOne
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) DeleteOne(user *global.User, artId string, pos int) error {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "DeleteOneTransitStock", "删除一个TransitStock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(artId, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId, pos)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.SelectOne
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) SelectOne(user *global.User, artId string, pos int) (*model.TransitStock, error) {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "SelectOneTransitStock", "查询一个TransitStock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(artId, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.UpdateOne
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) UpdateOne(user *global.User, entity *model.TransitStock) error {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "UpdateOneTransitStock", "修改一个TransitStock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ArtId, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.Insert
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) Insert(user *global.User, entities *[]model.TransitStock) error {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "InsertTransitStock", "插入多个TransitStock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.Pos)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.Delete
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) Delete(user *global.User, entities *[]model.TransitStock) error {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "DeleteTransitStock", "删除多个TransitStock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.Pos)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.Select
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.TransitStock, error) {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "SelectTransitStock", "查询TransitStock")

	condition := DefaultConditionOfTransitStockAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "SelectTransitStock", "查询TransitStock")

	condition := DefaultConditionOfTransitStockAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_AS/services/wm/TransitStockService.Update
 *
 ******************************************************************************/
func (impl *TransitStockServiceImplement) Update(user *global.User, entities *[]model.TransitStock) error {

	grmi.Log(user, "/services/wm/implments/TransitStock.service.impl.go", "UpdateTransitStock", "修改多个TransitStock")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewTransitStockDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.Pos)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
