// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package as

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/as"
	"LAPP_AS/web/middleware/jwts"
	"LAPP_AS/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterOneScheduler(party router.Party, httpMethod string, path string, method func(*global.User, *model.Scheduler) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.Scheduler)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterIDOfScheduler(party router.Party, httpMethod string, path string, method func(*global.User, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		schedulerId, err := ctx.Params().GetInt("schedulerId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, schedulerId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterInsertOneScheduler(party router.Party, path string, method func(*global.User, *model.Scheduler) error) {

	RegisterOneScheduler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterDeleteOneScheduler(party router.Party, path string, method func(*global.User, int) error) {

	RegisterIDOfScheduler(party, "DELETE", path+"/{schedulerId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterSelectOneScheduler(party router.Party, path string, method func(*global.User, int) (*model.Scheduler, error)) {

	party.Get(path+"/{schedulerId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		schedulerId, err := ctx.Params().GetInt("schedulerId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, schedulerId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterUpdateOneScheduler(party router.Party, path string, method func(*global.User, *model.Scheduler) error) {

	RegisterOneScheduler(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterMultiScheduler(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.Scheduler) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.Scheduler, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterInsertScheduler(party router.Party, path string, method func(*global.User, *[]model.Scheduler) error) {

	RegisterMultiScheduler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterDeleteScheduler(party router.Party, path string, method func(*global.User, *[]model.Scheduler) error) {

	RegisterMultiScheduler(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterSelectScheduler(party router.Party, path string, method func(*global.User, map[string]string) ([]model.Scheduler, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询Scheduler并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterQueryScheduler(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateScheduler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条Scheduler的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 15:51:34
 *
 ******************************************************************************/
func RegisterUpdateScheduler(party router.Party, path string, method func(*global.User, *[]model.Scheduler) error) {

	RegisterMultiScheduler(party, "PUT", path, method)
}

func RegisterCreateScheduler(party router.Party, path string, method func(*global.User, *model.Scheduler) error) {

	RegisterOneScheduler(party, "POST", path, method)
}

