// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/base"
	"LAPP_AS/web/middleware/jwts"
	"LAPP_AS/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterOnePersonSkilllst(party router.Party, httpMethod string, path string, method func(*global.User, *model.PersonSkilllst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PersonSkilllst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterIDOfPersonSkilllst(party router.Party, httpMethod string, path string, method func(*global.User, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		personNr, err := ctx.Params().GetInt("personNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		skillId := ctx.Params().GetString("skillId")

		err = method(user, personNr, skillId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertOnePersonSkilllst(party router.Party, path string, method func(*global.User, *model.PersonSkilllst) error) {

	RegisterOnePersonSkilllst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeleteOnePersonSkilllst(party router.Party, path string, method func(*global.User, int, string) error) {

	RegisterIDOfPersonSkilllst(party, "DELETE", path+"/{personNr:int}/{skillId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectOnePersonSkilllst(party router.Party, path string, method func(*global.User, int, string) (*model.PersonSkilllst, error)) {

	party.Get(path+"/{personNr:int}/{skillId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		personNr, err := ctx.Params().GetInt("personNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		skillId := ctx.Params().GetString("skillId")
		result, err := method(user, personNr, skillId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdateOnePersonSkilllst(party router.Party, path string, method func(*global.User, *model.PersonSkilllst) error) {

	RegisterOnePersonSkilllst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterMultiPersonSkilllst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.PersonSkilllst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PersonSkilllst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertPersonSkilllst(party router.Party, path string, method func(*global.User, *[]model.PersonSkilllst) error) {

	RegisterMultiPersonSkilllst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeletePersonSkilllst(party router.Party, path string, method func(*global.User, *[]model.PersonSkilllst) error) {

	RegisterMultiPersonSkilllst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectPersonSkilllst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.PersonSkilllst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryPersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PersonSkilllst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterQueryPersonSkilllst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePersonSkilllst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PersonSkilllst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdatePersonSkilllst(party router.Party, path string, method func(*global.User, *[]model.PersonSkilllst) error) {

	RegisterMultiPersonSkilllst(party, "PUT", path, method)
}
