// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/om"
	"LAPP_AS/web/middleware/jwts"
	"LAPP_AS/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterOneWOOperationStatus(party router.Party, httpMethod string, path string, method func(*global.User, *model.WOOperationStatus) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.WOOperationStatus)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterIDOfWOOperationStatus(party router.Party, httpMethod string, path string, method func(*global.User, string, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workOrderId := ctx.Params().GetString("workOrderId")
		operationNr, err := ctx.Params().GetInt("operationNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		splitNr, err := ctx.Params().GetInt("splitNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, workOrderId, operationNr, splitNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertOneWOOperationStatus(party router.Party, path string, method func(*global.User, *model.WOOperationStatus) error) {

	RegisterOneWOOperationStatus(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeleteOneWOOperationStatus(party router.Party, path string, method func(*global.User, string, int, int) error) {

	RegisterIDOfWOOperationStatus(party, "DELETE", path+"/{workOrderId:string}/{operationNr:int}/{splitNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectOneWOOperationStatus(party router.Party, path string, method func(*global.User, string, int, int) (*model.WOOperationStatus, error)) {

	party.Get(path+"/{workOrderId:string}/{operationNr:int}/{splitNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workOrderId := ctx.Params().GetString("workOrderId")
		operationNr, err := ctx.Params().GetInt("operationNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		splitNr, err := ctx.Params().GetInt("splitNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, workOrderId, operationNr, splitNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdateOneWOOperationStatus(party router.Party, path string, method func(*global.User, *model.WOOperationStatus) error) {

	RegisterOneWOOperationStatus(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterMultiWOOperationStatus(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.WOOperationStatus) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.WOOperationStatus, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertWOOperationStatus(party router.Party, path string, method func(*global.User, *[]model.WOOperationStatus) error) {

	RegisterMultiWOOperationStatus(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeleteWOOperationStatus(party router.Party, path string, method func(*global.User, *[]model.WOOperationStatus) error) {

	RegisterMultiWOOperationStatus(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectWOOperationStatus(party router.Party, path string, method func(*global.User, map[string]string) ([]model.WOOperationStatus, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WOOperationStatus并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterQueryWOOperationStatus(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateWOOperationStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条WOOperationStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdateWOOperationStatus(party router.Party, path string, method func(*global.User, *[]model.WOOperationStatus) error) {

	RegisterMultiWOOperationStatus(party, "PUT", path, method)
}
