// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/om"
	"LAPP_AS/web/middleware/jwts"
	"LAPP_AS/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterOneWOOperationToolLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.WOOperationToolLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.WOOperationToolLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterIDOfWOOperationToolLst(party router.Party, httpMethod string, path string, method func(*global.User, string, int, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workOrderId := ctx.Params().GetString("workOrderId")
		operationNr, err := ctx.Params().GetInt("operationNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		splitNr, err := ctx.Params().GetInt("splitNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		toolGrpId := ctx.Params().GetString("toolGrpId")

		err = method(user, workOrderId, operationNr, splitNr, toolGrpId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertOneWOOperationToolLst(party router.Party, path string, method func(*global.User, *model.WOOperationToolLst) error) {

	RegisterOneWOOperationToolLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeleteOneWOOperationToolLst(party router.Party, path string, method func(*global.User, string, int, int, string) error) {

	RegisterIDOfWOOperationToolLst(party, "DELETE", path+"/{workOrderId:string}/{operationNr:int}/{splitNr:int}/{toolGrpId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectOneWOOperationToolLst(party router.Party, path string, method func(*global.User, string, int, int, string) (*model.WOOperationToolLst, error)) {

	party.Get(path+"/{workOrderId:string}/{operationNr:int}/{splitNr:int}/{toolGrpId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workOrderId := ctx.Params().GetString("workOrderId")
		operationNr, err := ctx.Params().GetInt("operationNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		splitNr, err := ctx.Params().GetInt("splitNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		toolGrpId := ctx.Params().GetString("toolGrpId")
		result, err := method(user, workOrderId, operationNr, splitNr, toolGrpId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdateOneWOOperationToolLst(party router.Party, path string, method func(*global.User, *model.WOOperationToolLst) error) {

	RegisterOneWOOperationToolLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterMultiWOOperationToolLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.WOOperationToolLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.WOOperationToolLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertWOOperationToolLst(party router.Party, path string, method func(*global.User, *[]model.WOOperationToolLst) error) {

	RegisterMultiWOOperationToolLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeleteWOOperationToolLst(party router.Party, path string, method func(*global.User, *[]model.WOOperationToolLst) error) {

	RegisterMultiWOOperationToolLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectWOOperationToolLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.WOOperationToolLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WOOperationToolLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterQueryWOOperationToolLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateWOOperationToolLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条WOOperationToolLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdateWOOperationToolLst(party router.Party, path string, method func(*global.User, *[]model.WOOperationToolLst) error) {

	RegisterMultiWOOperationToolLst(party, "PUT", path, method)
}
