// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	"LAPP_AS/global"
	"LAPP_AS/grmi"
	model "LAPP_AS/models/wm"
	"LAPP_AS/web/middleware/jwts"
	"LAPP_AS/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterOneStock(party router.Party, httpMethod string, path string, method func(*global.User, *model.Stock) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.Stock)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterIDOfStock(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")

		err = method(user, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertOneStock(party router.Party, path string, method func(*global.User, *model.Stock) error) {

	RegisterOneStock(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeleteOneStock(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfStock(party, "DELETE", path+"/{artId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectOneStock(party router.Party, path string, method func(*global.User, string) (*model.Stock, error)) {

	party.Get(path+"/{artId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		result, err := method(user, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdateOneStock(party router.Party, path string, method func(*global.User, *model.Stock) error) {

	RegisterOneStock(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterMultiStock(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.Stock) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.Stock, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterInsertStock(party router.Party, path string, method func(*global.User, *[]model.Stock) error) {

	RegisterMultiStock(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterDeleteStock(party router.Party, path string, method func(*global.User, *[]model.Stock) error) {

	RegisterMultiStock(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterSelectStock(party router.Party, path string, method func(*global.User, map[string]string) ([]model.Stock, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询Stock并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterQueryStock(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateStock
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条Stock的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 14:06:46
 *
 ******************************************************************************/
func RegisterUpdateStock(party router.Party, path string, method func(*global.User, *[]model.Stock) error) {

	RegisterMultiStock(party, "PUT", path, method)
}
